/*! For license information please see 988.63950318fa6bf0a18bef.js.LICENSE.txt */
"use strict";(self.webpackChunkgrader_labextension=self.webpackChunkgrader_labextension||[]).push([[988],{47035:(e,a,l)=>{l.d(a,{A:()=>v});var t=l(40644),o=l(55285),r=l(93345),i=l(28919),n=l(24207),s=l(64111),d=l(31127),u=l(11848),c=l(3541),m=l(3663),b=l(74848);const T=["animation","className","component","height","style","variant","width"];let h,p,k,f,P=e=>e;const y=(0,n.keyframes)(h||(h=P`
  0% {
    opacity: 1;
  }

  50% {
    opacity: 0.4;
  }

  100% {
    opacity: 1;
  }
`)),g=(0,n.keyframes)(p||(p=P`
  0% {
    transform: translateX(-100%);
  }

  50% {
    /* +0.5s of delay between each loop */
    transform: translateX(100%);
  }

  100% {
    transform: translateX(100%);
  }
`)),x=(0,u.Ay)("span",{name:"MuiSkeleton",slot:"Root",overridesResolver:(e,a)=>{const{ownerState:l}=e;return[a.root,a[l.variant],!1!==l.animation&&a[l.animation],l.hasChildren&&a.withChildren,l.hasChildren&&!l.width&&a.fitContent,l.hasChildren&&!l.height&&a.heightAuto]}})((({theme:e,ownerState:a})=>{const l=(0,d.l_)(e.shape.borderRadius)||"px",t=(0,d.db)(e.shape.borderRadius);return(0,o.A)({display:"block",backgroundColor:e.vars?e.vars.palette.Skeleton.bg:(0,n.alpha)(e.palette.text.primary,"light"===e.palette.mode?.11:.13),height:"1.2em"},"text"===a.variant&&{marginTop:0,marginBottom:0,height:"auto",transformOrigin:"0 55%",transform:"scale(1, 0.60)",borderRadius:`${t}${l}/${Math.round(t/.6*10)/10}${l}`,"&:empty:before":{content:'"\\00a0"'}},"circular"===a.variant&&{borderRadius:"50%"},"rounded"===a.variant&&{borderRadius:(e.vars||e).shape.borderRadius},a.hasChildren&&{"& > *":{visibility:"hidden"}},a.hasChildren&&!a.width&&{maxWidth:"fit-content"},a.hasChildren&&!a.height&&{height:"auto"})}),(({ownerState:e})=>"pulse"===e.animation&&(0,n.css)(k||(k=P`
      animation: ${0} 2s ease-in-out 0.5s infinite;
    `),y)),(({ownerState:e,theme:a})=>"wave"===e.animation&&(0,n.css)(f||(f=P`
      position: relative;
      overflow: hidden;

      /* Fix bug in Safari https://bugs.webkit.org/show_bug.cgi?id=68196 */
      -webkit-mask-image: -webkit-radial-gradient(white, black);

      &::after {
        animation: ${0} 2s linear 0.5s infinite;
        background: linear-gradient(
          90deg,
          transparent,
          ${0},
          transparent
        );
        content: '';
        position: absolute;
        transform: translateX(-100%); /* Avoid flash during server-side hydration */
        bottom: 0;
        left: 0;
        right: 0;
        top: 0;
      }
    `),g,(a.vars||a).palette.action.hover))),v=r.forwardRef((function(e,a){const l=(0,c.A)({props:e,name:"MuiSkeleton"}),{animation:r="pulse",className:n,component:d="span",height:u,style:h,variant:p="text",width:k}=l,f=(0,t.A)(l,T),P=(0,o.A)({},l,{animation:r,component:d,variant:p,hasChildren:Boolean(f.children)}),y=(e=>{const{classes:a,variant:l,animation:t,hasChildren:o,width:r,height:i}=e,n={root:["root",l,t,o&&"withChildren",o&&!r&&"fitContent",o&&!i&&"heightAuto"]};return(0,s.A)(n,m.E,a)})(P);return(0,b.jsx)(x,(0,o.A)({as:d,ref:a,className:(0,i.A)(y.root,n),ownerState:P},f,{style:(0,o.A)({width:k,height:u},h)}))}))},3663:(e,a,l)=>{l.d(a,{A:()=>i,E:()=>r});var t=l(27553),o=l(17245);function r(e){return(0,o.Ay)("MuiSkeleton",e)}const i=(0,t.A)("MuiSkeleton",["root","text","rectangular","rounded","circular","pulse","wave","withChildren","fitContent","heightAuto"])},31127:(e,a,l)=>{function t(e){return String(parseFloat(e)).length===String(e).length}function o(e){return String(e).match(/[\d.\-+]*\s*(.*)/)[1]||""}function r(e){return parseFloat(e)}function i(e){return(a,l)=>{const t=o(a);if(t===l)return a;let i=r(a);"px"!==t&&("em"===t||"rem"===t)&&(i=r(a)*r(e));let n=i;if("px"!==l)if("em"===l)n=i/r(e);else{if("rem"!==l)return a;n=i/r(e)}return parseFloat(n.toFixed(5))+l}}function n({size:e,grid:a}){const l=e-e%a,t=l+a;return e-l<t-e?l:t}function s({lineHeight:e,pixels:a,htmlFontSize:l}){return a/(e*l)}function d({cssProperty:e,min:a,max:l,unit:t="rem",breakpoints:o=[600,900,1200],transform:r=null}){const i={[e]:`${a}${t}`},n=(l-a)/o[o.length-1];return o.forEach((l=>{let o=a+n*l;null!==r&&(o=r(o)),i[`@media (min-width:${l}px)`]={[e]:`${Math.round(1e4*o)/1e4}${t}`}})),i}l.d(a,{I3:()=>i,VR:()=>n,a9:()=>t,db:()=>r,l_:()=>o,qW:()=>s,yL:()=>d})},26988:(e,a,l)=>{l.r(a),l.d(a,{ArrowDropDownIcon:()=>Dl.iV,ArrowLeftIcon:()=>Dl.A6,ArrowRightIcon:()=>Dl.fl,CalendarIcon:()=>Dl.CT,ClearIcon:()=>Dl.vu,ClockIcon:()=>Dl.O4,DEFAULT_DESKTOP_MODE_MEDIA_QUERY:()=>Al.jX,DEFAULT_LOCALE:()=>B.X,DateCalendar:()=>Wa.x,DateField:()=>La,DatePicker:()=>Wl,DatePickerToolbar:()=>xl,DateRangeIcon:()=>Dl.Z5,DateTimeField:()=>Aa.I,DateTimePicker:()=>dt.K,DateTimePickerTabs:()=>ut.U,DateTimePickerToolbar:()=>mt.l,DayCalendarSkeleton:()=>ul,DesktopDatePicker:()=>Nl,DesktopDateTimePicker:()=>Tt.U,DesktopTimePicker:()=>ot,DigitalClock:()=>s.N,LocalizationProvider:()=>b.$,MobileDatePicker:()=>Vl,MobileDateTimePicker:()=>ht.E,MobileTimePicker:()=>rt,MonthCalendar:()=>Ha.T,MuiPickersAdapterContext:()=>b.F,MultiSectionDigitalClock:()=>u.z,PickersActionBar:()=>gt.L,PickersCalendarHeader:()=>ja.V,PickersDay:()=>T.a,PickersLayout:()=>Rl.CJ,PickersLayoutContentWrapper:()=>Rl.IU,PickersLayoutRoot:()=>Rl.Kr,PickersShortcuts:()=>xt.f,StaticDatePicker:()=>jl,StaticDateTimePicker:()=>ft,StaticTimePicker:()=>st,TimeClock:()=>t.a,TimeField:()=>Va,TimeIcon:()=>Dl.b1,TimePicker:()=>nt,TimePickerToolbar:()=>Ql,YearCalendar:()=>Ya.i,beBY:()=>P,caES:()=>x,clockClasses:()=>o.N,clockNumberClasses:()=>r.q,clockPointerClasses:()=>n.S,csCZ:()=>L,daDK:()=>w,dateCalendarClasses:()=>Ba.r,datePickerToolbarClasses:()=>fl,dateTimePickerTabsClasses:()=>ct.g,dateTimePickerToolbarClasses:()=>bt.d,dayCalendarSkeletonClasses:()=>tl,dayPickerClasses:()=>Ra.n,deDE:()=>V,digitalClockClasses:()=>d.X,elGR:()=>W,enUS:()=>B.c,esES:()=>O,eu:()=>H,faIR:()=>Y,fiFI:()=>q,frFR:()=>_,getDateCalendarUtilityClass:()=>Ba.$,getDayCalendarSkeletonUtilityClass:()=>ll,getDigitalClockUtilityClass:()=>d.L,getMonthCalendarUtilityClass:()=>Ia.x,getMultiSectionDigitalClockUtilityClass:()=>m.h,getPickersDayUtilityClass:()=>h.m,getTimeClockUtilityClass:()=>i.Y,getYearCalendarUtilityClass:()=>Ka.o,heIL:()=>Q,huHU:()=>le,isIS:()=>re,itIT:()=>se,jaJP:()=>ce,koKR:()=>Te,kzKZ:()=>ke,mk:()=>fe,monthCalendarClasses:()=>Ia.b,multiSectionDigitalClockClasses:()=>m.L,multiSectionDigitalClockSectionClasses:()=>c.w,nbNO:()=>ge,nlNL:()=>Me,pickersCalendarHeaderClasses:()=>Ea.H,pickersDayClasses:()=>h.Q,pickersFadeTransitionGroupClasses:()=>za.r,pickersLayoutClasses:()=>yt.k,pickersMonthClasses:()=>Fa.m,pickersSlideTransitionClasses:()=>Oa.U,pickersYearClasses:()=>Ua.z,plPL:()=>$e,ptBR:()=>Ce,renderDateViewCalendar:()=>wl.W,renderDigitalClockTimeView:()=>at.$W,renderMultiSectionDigitalClockTimeView:()=>at.$8,renderTimeViewClock:()=>at.Zo,roRO:()=>Se,ruRU:()=>Re,skSK:()=>Ee,svSE:()=>Ie,timeClockClasses:()=>i.G,timePickerToolbarClasses:()=>Ul,trTR:()=>Ke,ukUA:()=>Ze,unstable_useDateField:()=>Pa,unstable_useDateTimeField:()=>Sa.p,unstable_useTimeField:()=>$a,urPK:()=>Ge,useClearableField:()=>ya.Z,usePickerLayout:()=>Pt.A,viVN:()=>ea,yearCalendarClasses:()=>Ka.E,zhCN:()=>ta,zhHK:()=>ia});var t=l(83396),o=l(12454),r=l(72713),i=l(84895),n=l(32127),s=l(44149),d=l(91181),u=l(27899),c=l(15160),m=l(81937),b=l(75737),T=l(63967),h=l(61099),p=l(33230);const k={hours:"гадзіны",minutes:"хвіліны",seconds:"секунды",meridiem:"мерыдыем"},f={previousMonth:"Папярэдні месяц",nextMonth:"Наступны месяц",openPreviousView:"адкрыць папярэдні выгляд",openNextView:"адкрыць наступны выгляд",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"гадавы выгляд адкрыты, перайсці да каляндарнага выгляду":"каляндарны выгляд адкрыты, перайсці да гадавога выгляду",start:"Пачатак",end:"Канец",cancelButtonLabel:"Адмена",clearButtonLabel:"Ачысціць",okButtonLabel:"OK",todayButtonLabel:"Сёння",datePickerToolbarTitle:"Абраць дату",dateTimePickerToolbarTitle:"Абраць дату і час",timePickerToolbarTitle:"Абраць час",dateRangePickerToolbarTitle:"Абраць каляндарны перыяд",clockLabelText:(e,a,l)=>`Абярыце ${k[e]}. ${null===a?"Час не абраны":`Абраны час ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} гадзін`,minutesClockNumberText:e=>`${e} хвілін`,secondsClockNumberText:e=>`${e} секунд`,selectViewText:e=>`Абярыце ${k[e]}`,calendarWeekNumberHeaderLabel:"Нумар тыдня",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Тыдзень ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Абраць дату, абрана дата  ${a.format(e,"fullDate")}`:"Абраць дату",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Абраць час, абрыны час  ${a.format(e,"fullTime")}`:"Абраць час",timeTableLabel:"абраць час",dateTableLabel:"абраць дату",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},P=(0,p.r)(f),y={hours:"les hores",minutes:"els minuts",seconds:"els segons",meridiem:"meridiem"},g={previousMonth:"Últim mes",nextMonth:"Pròxim mes",openPreviousView:"obrir l'última vista",openNextView:"obrir la següent vista",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"la vista de l'any està oberta, canvie a la vista de calendari":"la vista de calendari està oberta, canvie a la vista de l'any",start:"Començar",end:"Terminar",cancelButtonLabel:"Cancel·lar",clearButtonLabel:"Netejar",okButtonLabel:"OK",todayButtonLabel:"Hui",datePickerToolbarTitle:"Seleccionar data",dateTimePickerToolbarTitle:"Seleccionar data i hora",timePickerToolbarTitle:"Seleccionar hora",dateRangePickerToolbarTitle:"Seleccionar rang de dates",clockLabelText:(e,a,l)=>`Seleccione ${y[e]}. ${null===a?"Sense temps seleccionat":`El temps seleccionat és ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} hores`,minutesClockNumberText:e=>`${e} minuts`,secondsClockNumberText:e=>`${e} segons`,selectViewText:e=>`Seleccionar ${y[e]}`,calendarWeekNumberHeaderLabel:"Número de setmana",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Setmana ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Tria la data, la data triada és ${a.format(e,"fullDate")}`:"Tria la data",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Tria l'hora, l'hora triada és ${a.format(e,"fullTime")}`:"Tria l'hora",timeTableLabel:"tria la data",dateTableLabel:"tria l'hora",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},x=(0,p.r)(g),v={hours:"Hodiny",minutes:"Minuty",seconds:"Sekundy",meridiem:"Odpoledne"},M={previousMonth:"Předchozí měsíc",nextMonth:"Další měsíc",openPreviousView:"otevřít předchozí zobrazení",openNextView:"otevřít další zobrazení",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"roční zobrazení otevřeno, přepněte do zobrazení kalendáře":"zobrazení kalendáře otevřeno, přepněte do zobrazení roku",start:"Začátek",end:"Konec",cancelButtonLabel:"Zrušit",clearButtonLabel:"Vymazat",okButtonLabel:"Potvrdit",todayButtonLabel:"Dnes",datePickerToolbarTitle:"Vyberte datum",dateTimePickerToolbarTitle:"Vyberte datum a čas",timePickerToolbarTitle:"Vyberte čas",dateRangePickerToolbarTitle:"Vyberete rozmezí dat",clockLabelText:(e,a,l)=>{var t;return`${null!=(t=v[e])?t:e} vybrány. ${null===a?"Není vybrán čas":`Vybraný čas je ${l.format(a,"fullTime")}`}`},hoursClockNumberText:e=>`${e} hodin`,minutesClockNumberText:e=>`${e} minut`,secondsClockNumberText:e=>`${e} sekund`,selectViewText:e=>`Vyberte ${v[e]}`,calendarWeekNumberHeaderLabel:"Týden v roce",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`${e} týden v roce`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Vyberte datum, vybrané datum je ${a.format(e,"fullDate")}`:"Vyberte datum",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Vyberte čas, vybraný čas je ${a.format(e,"fullTime")}`:"Vyberte čas",timeTableLabel:"vyberte čas",dateTableLabel:"vyberte datum",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},L=(0,p.r)(M),D={hours:"Timer",minutes:"Minutter",seconds:"Sekunder",meridiem:"Meridiem"},$={previousMonth:"Forrige måned",nextMonth:"Næste måned",openPreviousView:"åben forrige visning",openNextView:"åben næste visning",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"årsvisning er åben, skift til kalendervisning":"kalendervisning er åben, skift til årsvisning",start:"Start",end:"Slut",cancelButtonLabel:"Annuller",clearButtonLabel:"Ryd",okButtonLabel:"OK",todayButtonLabel:"I dag",datePickerToolbarTitle:"Vælg dato",dateTimePickerToolbarTitle:"Vælg dato & tidspunkt",timePickerToolbarTitle:"Vælg tidspunkt",dateRangePickerToolbarTitle:"Vælg datointerval",clockLabelText:(e,a,l)=>{var t;return`Vælg ${null!=(t=D[e])?t:e}. ${null===a?"Intet tidspunkt valgt":`Valgte tidspunkt er ${l.format(a,"fullTime")}`}`},hoursClockNumberText:e=>`${e} timer`,minutesClockNumberText:e=>`${e} minutter`,secondsClockNumberText:e=>`${e} sekunder`,selectViewText:e=>`Vælg ${D[e]}`,calendarWeekNumberHeaderLabel:"Ugenummer",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Uge ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Vælg dato, valgte dato er ${a.format(e,"fullDate")}`:"Vælg dato",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Vælg tidspunkt, valgte tidspunkt er ${a.format(e,"fullTime")}`:"Vælg tidspunkt",timeTableLabel:"vælg tidspunkt",dateTableLabel:"vælg dato",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},w=(0,p.r)($),N={hours:"Stunden",minutes:"Minuten",seconds:"Sekunden",meridiem:"Meridiem"},C={previousMonth:"Letzter Monat",nextMonth:"Nächster Monat",openPreviousView:"Letzte Ansicht öffnen",openNextView:"Nächste Ansicht öffnen",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"Jahresansicht ist geöffnet, zur Kalenderansicht wechseln":"Kalenderansicht ist geöffnet, zur Jahresansicht wechseln",start:"Beginn",end:"Ende",cancelButtonLabel:"Abbrechen",clearButtonLabel:"Löschen",okButtonLabel:"OK",todayButtonLabel:"Heute",datePickerToolbarTitle:"Datum auswählen",dateTimePickerToolbarTitle:"Datum & Uhrzeit auswählen",timePickerToolbarTitle:"Uhrzeit auswählen",dateRangePickerToolbarTitle:"Datumsbereich auswählen",clockLabelText:(e,a,l)=>{var t;return`${null!=(t=N[e])?t:e} auswählen. ${null===a?"Keine Uhrzeit ausgewählt":`Gewählte Uhrzeit ist ${l.format(a,"fullTime")}`}`},hoursClockNumberText:e=>`${e} ${N.hours}`,minutesClockNumberText:e=>`${e} ${N.minutes}`,secondsClockNumberText:e=>`${e}  ${N.seconds}`,selectViewText:e=>`${N[e]} auswählen`,calendarWeekNumberHeaderLabel:"Kalenderwoche",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Woche ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Datum auswählen, gewähltes Datum ist ${a.format(e,"fullDate")}`:"Datum auswählen",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Uhrzeit auswählen, gewählte Uhrzeit ist ${a.format(e,"fullTime")}`:"Uhrzeit auswählen",fieldClearLabel:"Wert leeren",timeTableLabel:"Uhrzeit auswählen",dateTableLabel:"Datum auswählen",fieldYearPlaceholder:e=>"J".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"TT",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},V=(0,p.r)(C),A={hours:"ώρες",minutes:"λεπτά",seconds:"δευτερόλεπτα",meridiem:"μεσημβρία"},S={previousMonth:"Προηγούμενος μήνας",nextMonth:"Επόμενος μήνας",openPreviousView:"ανοίγμα προηγούμενης προβολή",openNextView:"ανοίγμα επόμενης προβολή",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"η προβολή έτους είναι ανοιχτή, μεταβείτε στην προβολή ημερολογίου":"η προβολή ημερολογίου είναι ανοιχτή, μεταβείτε στην προβολή έτους",start:"Αρχή",end:"Τέλος",cancelButtonLabel:"Άκυρο",clearButtonLabel:"Καθαρισμός",okButtonLabel:"OK",todayButtonLabel:"Σήμερα",datePickerToolbarTitle:"Επιλέξτε ημερομηνία",dateTimePickerToolbarTitle:"Επιλέξτε ημερομηνία και ώρα",timePickerToolbarTitle:"Επιλέξτε ώρα",dateRangePickerToolbarTitle:"Επιλέξτε εύρος ημερομηνιών",clockLabelText:(e,a,l)=>`Επιλέξτε ${A[e]}. ${null===a?"Δεν έχει επιλεγεί ώρα":`Η επιλεγμένη ώρα είναι ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} ώρες`,minutesClockNumberText:e=>`${e} λεπτά`,secondsClockNumberText:e=>`${e} δευτερόλεπτα`,selectViewText:e=>`Επιλέξτε ${A[e]}`,calendarWeekNumberHeaderLabel:"Αριθμός εβδομάδας",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Εβδομάδα ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Επιλέξτε ημερομηνία, η επιλεγμένη ημερομηνία είναι ${a.format(e,"fullDate")}`:"Επιλέξτε ημερομηνία",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Επιλέξτε ώρα, η επιλεγμένη ώρα είναι ${a.format(e,"fullTime")}`:"Επιλέξτε ώρα",timeTableLabel:"επιλέξτε ώρα",dateTableLabel:"επιλέξτε ημερομηνία",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},W=(0,p.r)(S);var B=l(74165);const R={hours:"las horas",minutes:"los minutos",seconds:"los segundos",meridiem:"meridiano"},z={previousMonth:"Último mes",nextMonth:"Próximo mes",openPreviousView:"abrir la última vista",openNextView:"abrir la siguiente vista",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"la vista del año está abierta, cambie a la vista de calendario":"la vista de calendario está abierta, cambie a la vista del año",start:"Empezar",end:"Terminar",cancelButtonLabel:"Cancelar",clearButtonLabel:"Limpiar",okButtonLabel:"OK",todayButtonLabel:"Hoy",datePickerToolbarTitle:"Seleccionar fecha",dateTimePickerToolbarTitle:"Seleccionar fecha y hora",timePickerToolbarTitle:"Seleccionar hora",dateRangePickerToolbarTitle:"Seleccionar rango de fecha",clockLabelText:(e,a,l)=>`Seleccione ${R[e]}. ${null===a?"No hay hora seleccionada":`La hora seleccionada es ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} horas`,minutesClockNumberText:e=>`${e} minutos`,secondsClockNumberText:e=>`${e} segundos`,selectViewText:e=>`Seleccionar ${R[e]}`,calendarWeekNumberHeaderLabel:"Número de semana",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Semana ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Elige fecha, la fecha elegida es ${a.format(e,"fullDate")}`:"Elige fecha",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Elige hora, la hora elegida es ${a.format(e,"fullTime")}`:"Elige hora",fieldClearLabel:"Limpiar valor",timeTableLabel:"elige hora",dateTableLabel:"elige fecha",fieldYearPlaceholder:e=>"A".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},O=(0,p.r)(z),E={hours:"orduak",minutes:"minutuak",seconds:"segunduak",meridiem:"meridianoa"},j={previousMonth:"Azken hilabetea",nextMonth:"Hurrengo hilabetea",openPreviousView:"azken bista ireki",openNextView:"hurrengo bista ireki",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"urteko bista irekita dago, aldatu egutegi bistara":"egutegi bista irekita dago, aldatu urteko bistara",start:"Hasi",end:"Bukatu",cancelButtonLabel:"Utxi",clearButtonLabel:"Garbitu",okButtonLabel:"OK",todayButtonLabel:"Gaur",datePickerToolbarTitle:"Data aukeratu",dateTimePickerToolbarTitle:"Data eta ordua aukeratu",timePickerToolbarTitle:"Ordua aukeratu",dateRangePickerToolbarTitle:"Data tartea aukeratu",clockLabelText:(e,a,l)=>`Aukeratu ${E[e]}. ${null===a?"Ez da ordurik aukertau":`Aukeratutako ordua ${l.format(a,"fullTime")} da`}`,hoursClockNumberText:e=>`${e} ordu`,minutesClockNumberText:e=>`${e} minutu`,secondsClockNumberText:e=>`${e} segundu`,selectViewText:e=>`Aukeratu ${E[e]}`,calendarWeekNumberHeaderLabel:"Astea zenbakia",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`${e} astea`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Data aukeratu, aukeratutako data ${a.format(e,"fullDate")} da`:"Data aukeratu",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Ordua aukeratu, aukeratutako ordua ${a.format(e,"fullTime")} da`:"Ordua aukeratu",fieldClearLabel:"Balioa garbitu",timeTableLabel:"ordua aukeratu",dateTableLabel:"data aukeratu",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},H=(0,p.r)(j),I={hours:"ساعت ها",minutes:"دقیقه ها",seconds:"ثانیه ها",meridiem:"بعد از ظهر"},F={previousMonth:"ماه گذشته",nextMonth:"ماه آینده",openPreviousView:"نمای قبلی",openNextView:"نمای بعدی",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"نمای سال باز است، رفتن به نمای تقویم":"نمای تقویم باز است، رفتن به نمای سال",start:"شروع",end:"پایان",cancelButtonLabel:"لغو",clearButtonLabel:"پاک کردن",okButtonLabel:"اوکی",todayButtonLabel:"امروز",datePickerToolbarTitle:"تاریخ را انتخاب کنید",dateTimePickerToolbarTitle:"تاریخ و ساعت را انتخاب کنید",timePickerToolbarTitle:"ساعت را انتخاب کنید",dateRangePickerToolbarTitle:"محدوده تاریخ را انتخاب کنید",clockLabelText:(e,a,l)=>` را انتخاب کنید ${I[e]}. ${null===a?"هیچ ساعتی انتخاب نشده است":`ساعت انتخاب ${l.format(a,"fullTime")} می باشد`}`,hoursClockNumberText:e=>`${e} ساعت ها`,minutesClockNumberText:e=>`${e} دقیقه ها`,secondsClockNumberText:e=>`${e} ثانیه ها`,selectViewText:e=>` را انتخاب کنید ${I[e]}`,calendarWeekNumberHeaderLabel:"عدد هفته",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`هفته ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`تاریخ را انتخاب کنید، تاریخ انتخاب شده ${a.format(e,"fullDate")} می باشد`:"تاریخ را انتخاب کنید",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`ساعت را انتخاب کنید، ساعت انتخاب شده ${a.format(e,"fullTime")} می باشد`:"ساعت را انتخاب کنید",timeTableLabel:"انتخاب تاریخ",dateTableLabel:"انتخاب ساعت",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Y=(0,p.r)(F),K={hours:"tunnit",minutes:"minuutit",seconds:"sekuntit",meridiem:"iltapäivä"},U={previousMonth:"Edellinen kuukausi",nextMonth:"Seuraava kuukausi",openPreviousView:"avaa edellinen kuukausi",openNextView:"avaa seuraava kuukausi",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"vuosinäkymä on auki, vaihda kalenterinäkymään":"kalenterinäkymä on auki, vaihda vuosinäkymään",start:"Alku",end:"Loppu",cancelButtonLabel:"Peruuta",clearButtonLabel:"Tyhjennä",okButtonLabel:"OK",todayButtonLabel:"Tänään",datePickerToolbarTitle:"Valitse päivä",dateTimePickerToolbarTitle:"Valitse päivä ja aika",timePickerToolbarTitle:"Valitse aika",dateRangePickerToolbarTitle:"Valitse aikaväli",clockLabelText:(e,a,l)=>`Valitse ${K[e]}. ${null===a?"Ei aikaa valittuna":`Valittu aika on ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} tuntia`,minutesClockNumberText:e=>`${e} minuuttia`,secondsClockNumberText:e=>`${e} sekunttia`,selectViewText:e=>`Valitse ${K[e]}`,calendarWeekNumberHeaderLabel:"Viikko",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Viikko ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Valitse päivä, valittu päivä on ${a.format(e,"fullDate")}`:"Valitse päivä",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Valitse aika, valittu aika on ${a.format(e,"fullTime")}`:"Valitse aika",timeTableLabel:"valitse aika",dateTableLabel:"valitse päivä",fieldYearPlaceholder:e=>"V".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"KKKK":"KK",fieldDayPlaceholder:()=>"PP",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"tt",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},q=(0,p.r)(U),Z={hours:"heures",minutes:"minutes",seconds:"secondes",meridiem:"méridien"},X={previousMonth:"Mois précédent",nextMonth:"Mois suivant",openPreviousView:"Ouvrir la vue précédente",openNextView:"Ouvrir la vue suivante",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"La vue année est ouverte, ouvrir la vue calendrier":"La vue calendrier est ouverte, ouvrir la vue année",start:"Début",end:"Fin",cancelButtonLabel:"Annuler",clearButtonLabel:"Vider",okButtonLabel:"OK",todayButtonLabel:"Aujourd'hui",datePickerToolbarTitle:"Choisir une date",dateTimePickerToolbarTitle:"Choisir la date et l'heure",timePickerToolbarTitle:"Choisir l'heure",dateRangePickerToolbarTitle:"Choisir la plage de dates",clockLabelText:(e,a,l)=>`Choix des ${Z[e]}. ${null===a?"Aucune heure choisie":`L'heure choisie est ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} heures`,minutesClockNumberText:e=>`${e} minutes`,secondsClockNumberText:e=>`${e} secondes`,selectViewText:e=>`Choisir ${Z[e]}`,calendarWeekNumberHeaderLabel:"Semaine",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Semaine ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Choisir la date, la date sélectionnée est ${a.format(e,"fullDate")}`:"Choisir la date",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Choisir l'heure, l'heure sélectionnée est ${a.format(e,"fullTime")}`:"Choisir l'heure",timeTableLabel:"choix de l'heure",dateTableLabel:"choix de la date",fieldYearPlaceholder:e=>"A".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"JJ",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},_=(0,p.r)(X),G={hours:"שעות",minutes:"דקות",seconds:"שניות",meridiem:"מרידיאם"},J={previousMonth:"חודש קודם",nextMonth:"חודש הבא",openPreviousView:"תצוגה קודמת",openNextView:"תצוגה הבאה",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"תצוגת שנה פתוחה, מעבר לתצוגת לוח שנה":"תצוגת לוח שנה פתוחה, מעבר לתצוגת שנה",start:"תחילה",end:"סיום",cancelButtonLabel:"ביטול",clearButtonLabel:"ניקוי",okButtonLabel:"אישור",todayButtonLabel:"היום",datePickerToolbarTitle:"בחירת תאריך",dateTimePickerToolbarTitle:"בחירת תאריך ושעה",timePickerToolbarTitle:"בחירת שעה",dateRangePickerToolbarTitle:"בחירת טווח תאריכים",clockLabelText:(e,a,l)=>`בחירת ${G[e]}. ${null===a?"לא נבחרה שעה":`השעה הנבחרת היא ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} שעות`,minutesClockNumberText:e=>`${e} דקות`,secondsClockNumberText:e=>`${e} שניות`,selectViewText:e=>`בחירת ${G[e]}`,calendarWeekNumberHeaderLabel:"שבוע מספר",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`שבוע ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`בחירת תאריך, התאריך שנבחר הוא ${a.format(e,"fullDate")}`:"בחירת תאריך",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`בחירת שעה, השעה שנבחרה היא ${a.format(e,"fullTime")}`:"בחירת שעה",timeTableLabel:"בחירת שעה",dateTableLabel:"בחירת תאריך",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Q=(0,p.r)(J),ee={hours:"Óra",minutes:"Perc",seconds:"Másodperc",meridiem:"Délután"},ae={previousMonth:"Előző hónap",nextMonth:"Következő hónap",openPreviousView:"Előző nézet megnyitása",openNextView:"Következő nézet megnyitása",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"az évválasztó már nyitva, váltson a naptárnézetre":"a naptárnézet már nyitva, váltson az évválasztóra",start:"Kezdő dátum",end:"Záró dátum",cancelButtonLabel:"Mégse",clearButtonLabel:"Törlés",okButtonLabel:"OK",todayButtonLabel:"Ma",datePickerToolbarTitle:"Dátum kiválasztása",dateTimePickerToolbarTitle:"Dátum és idő kiválasztása",timePickerToolbarTitle:"Idő kiválasztása",dateRangePickerToolbarTitle:"Dátumhatárok kiválasztása",clockLabelText:(e,a,l)=>{var t;return`${null!=(t=ee[e])?t:e} kiválasztása. ${null===a?"Nincs kiválasztva idő":`A kiválasztott idő ${l.format(a,"fullTime")}`}`},hoursClockNumberText:e=>`${e} ${ee.hours.toLowerCase()}`,minutesClockNumberText:e=>`${e} ${ee.minutes.toLowerCase()}`,secondsClockNumberText:e=>`${e}  ${ee.seconds.toLowerCase()}`,selectViewText:e=>`${ee[e]} kiválasztása`,calendarWeekNumberHeaderLabel:"Hét",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`${e}. hét`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Válasszon dátumot, a kiválasztott dátum: ${a.format(e,"fullDate")}`:"Válasszon dátumot",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Válasszon időt, a kiválasztott idő: ${a.format(e,"fullTime")}`:"Válasszon időt",fieldClearLabel:"Tartalom ürítése",timeTableLabel:"válasszon időt",dateTableLabel:"válasszon dátumot",fieldYearPlaceholder:e=>"É".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"HHHH":"HH",fieldDayPlaceholder:()=>"NN",fieldHoursPlaceholder:()=>"óó",fieldMinutesPlaceholder:()=>"pp",fieldSecondsPlaceholder:()=>"mm",fieldMeridiemPlaceholder:()=>"dd"},le=(0,p.r)(ae),te={hours:"klukkustundir",minutes:"mínútur",seconds:"sekúndur",meridiem:"eftirmiðdagur"},oe={previousMonth:"Fyrri mánuður",nextMonth:"Næsti mánuður",openPreviousView:"opna fyrri skoðun",openNextView:"opna næstu skoðun",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"ársskoðun er opin, skipta yfir í dagatalsskoðun":"dagatalsskoðun er opin, skipta yfir í ársskoðun",start:"Upphaf",end:"Endir",cancelButtonLabel:"Hætta við",clearButtonLabel:"Hreinsa",okButtonLabel:"OK",todayButtonLabel:"Í dag",datePickerToolbarTitle:"Velja dagsetningu",dateTimePickerToolbarTitle:"Velja dagsetningu og tíma",timePickerToolbarTitle:"Velja tíma",dateRangePickerToolbarTitle:"Velja tímabil",clockLabelText:(e,a,l)=>`Velja ${te[e]}. ${null===a?"Enginn tími valinn":`Valinn tími er ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} klukkustundir`,minutesClockNumberText:e=>`${e} mínútur`,secondsClockNumberText:e=>`${e} sekúndur`,selectViewText:e=>`Velja ${te[e]}`,calendarWeekNumberHeaderLabel:"Vikunúmer",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Vika ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Velja dagsetningu, valin dagsetning er ${a.format(e,"fullDate")}`:"Velja dagsetningu",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Velja tíma, valinn tími er ${a.format(e,"fullTime")}`:"Velja tíma",timeTableLabel:"velja tíma",dateTableLabel:"velja dagsetningu",fieldYearPlaceholder:e=>"Á".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"kk",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"ee"},re=(0,p.r)(oe),ie={hours:"le ore",minutes:"i minuti",seconds:"i secondi",meridiem:"il meridiano"},ne={previousMonth:"Mese precedente",nextMonth:"Mese successivo",openPreviousView:"apri la vista precedente",openNextView:"apri la vista successiva",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"la vista dell'anno è aperta, passare alla vista del calendario":"la vista dell'calendario è aperta, passare alla vista dell'anno",start:"Inizio",end:"Fine",cancelButtonLabel:"Cancellare",clearButtonLabel:"Sgomberare",okButtonLabel:"OK",todayButtonLabel:"Oggi",datePickerToolbarTitle:"Seleziona data",dateTimePickerToolbarTitle:"Seleziona data e orario",timePickerToolbarTitle:"Seleziona orario",dateRangePickerToolbarTitle:"Seleziona intervallo di date",clockLabelText:(e,a,l)=>`Seleziona ${ie[e]}. ${null===a?"Nessun orario selezionato":`L'ora selezionata è ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} ore`,minutesClockNumberText:e=>`${e} minuti`,secondsClockNumberText:e=>`${e} secondi`,selectViewText:e=>`Seleziona ${ie[e]}`,calendarWeekNumberHeaderLabel:"Numero settimana",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Settimana ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Scegli la data, la data selezionata è ${a.format(e,"fullDate")}`:"Scegli la data",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Scegli l'ora, l'ora selezionata è ${a.format(e,"fullTime")}`:"Scegli l'ora",timeTableLabel:"scegli un'ora",dateTableLabel:"scegli una data",fieldYearPlaceholder:e=>"A".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"GG",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},se=(0,p.r)(ne),de={hours:"時間",minutes:"分",seconds:"秒",meridiem:"メリディム"},ue={previousMonth:"先月",nextMonth:"来月",openPreviousView:"前の表示を開く",openNextView:"次の表示を開く",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"年選択表示からカレンダー表示に切り替える":"カレンダー表示から年選択表示に切り替える",start:"開始",end:"終了",cancelButtonLabel:"キャンセル",clearButtonLabel:"クリア",okButtonLabel:"確定",todayButtonLabel:"今日",datePickerToolbarTitle:"日付を選択",dateTimePickerToolbarTitle:"日時を選択",timePickerToolbarTitle:"時間を選択",dateRangePickerToolbarTitle:"日付の範囲を選択",clockLabelText:(e,a,l)=>{var t;return`${null!=(t=de[e])?t:e}を選択してください ${null===a?"時間が選択されていません":`選択した時間は ${l.format(a,"fullTime")} です`}`},hoursClockNumberText:e=>`${e} ${de.hours}`,minutesClockNumberText:e=>`${e} ${de.minutes}`,secondsClockNumberText:e=>`${e} ${de.seconds}`,selectViewText:e=>`を選択 ${de[e]}`,calendarWeekNumberHeaderLabel:"週番号",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`${e}週目`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`日付を選択してください。選択した日付は ${a.format(e,"fullDate")} です`:"日付を選択してください",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`時間を選択してください。選択した時間は ${a.format(e,"fullTime")} です`:"時間を選択してください",timeTableLabel:"時間を選択",dateTableLabel:"日付を選択",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},ce=(0,p.r)(ue),me={hours:"시간을",minutes:"분을",seconds:"초를",meridiem:"메리디엠"},be={previousMonth:"이전 달",nextMonth:"다음 달",openPreviousView:"이전 화면 보기",openNextView:"다음 화면 보기",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"연도 선택 화면에서 달력 화면으로 전환하기":"달력 화면에서 연도 선택 화면으로 전환하기",start:"시작",end:"종료",cancelButtonLabel:"취소",clearButtonLabel:"초기화",okButtonLabel:"확인",todayButtonLabel:"오늘",datePickerToolbarTitle:"날짜 선택하기",dateTimePickerToolbarTitle:"날짜 & 시간 선택하기",timePickerToolbarTitle:"시간 선택하기",dateRangePickerToolbarTitle:"날짜 범위 선택하기",clockLabelText:(e,a,l)=>`${me[e]} 선택하세요. ${null===a?"시간을 선택하지 않았습니다.":`현재 선택된 시간은 ${l.format(a,"fullTime")}입니다.`}`,hoursClockNumberText:e=>`${e}시간`,minutesClockNumberText:e=>`${e}분`,secondsClockNumberText:e=>`${e}초`,selectViewText:e=>`${me[e]} 선택하기`,calendarWeekNumberHeaderLabel:"주 번호",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`${e}번째 주`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`날짜를 선택하세요. 현재 선택된 날짜는 ${a.format(e,"fullDate")}입니다.`:"날짜를 선택하세요",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`시간을 선택하세요. 현재 선택된 시간은 ${a.format(e,"fullTime")}입니다.`:"시간을 선택하세요",fieldClearLabel:"지우기",timeTableLabel:"선택한 시간",dateTableLabel:"선택한 날짜",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Te=(0,p.r)(be),he={hours:"Сағатты",minutes:"Минутты",seconds:"Секундты",meridiem:"Меридием"},pe={previousMonth:"Алдыңғы ай",nextMonth:"Келесі ай",openPreviousView:"Алдыңғы көріністі ашу",openNextView:"Келесі көріністі ашу",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"жылдық көріністі ашу, күнтізбе көрінісіне ауысу":"күнтізбе көрінісін ашу, жылдық көрінісіне ауысу",start:"Бастау",end:"Cоңы",cancelButtonLabel:"Бас тарту",clearButtonLabel:"Тазарту",okButtonLabel:"Ок",todayButtonLabel:"Бүгін",datePickerToolbarTitle:"Күнді таңдау",dateTimePickerToolbarTitle:"Күн мен уақытты таңдау",timePickerToolbarTitle:"Уақытты таңдау",dateRangePickerToolbarTitle:"Кезеңді таңдаңыз",clockLabelText:(e,a,l)=>`${he[e]} таңдау. ${null===a?"Уақыт таңдалмаған":`Таңдалған уақыт ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} сағат`,minutesClockNumberText:e=>`${e} минут`,secondsClockNumberText:e=>`${e} секунд`,selectViewText:e=>`${he[e]} таңдау`,calendarWeekNumberHeaderLabel:"Апта нөмірі",calendarWeekNumberHeaderText:"№",calendarWeekNumberAriaLabelText:e=>`Апта ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Күнді таңдаңыз, таңдалған күн ${a.format(e,"fullDate")}`:"Күнді таңдаңыз",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Уақытты таңдаңыз, таңдалған уақыт ${a.format(e,"fullTime")}`:"Уақытты таңдаңыз",timeTableLabel:"уақытты таңдау",dateTableLabel:"күнді таңдау",fieldYearPlaceholder:e=>"Ж".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"AAAA":"AA",fieldDayPlaceholder:()=>"КК",fieldHoursPlaceholder:()=>"сс",fieldMinutesPlaceholder:()=>"мм",fieldSecondsPlaceholder:()=>"сс",fieldMeridiemPlaceholder:()=>"(т|к)"},ke=(0,p.r)(pe),fe=(0,p.r)({previousMonth:"Предходен месец",nextMonth:"Следен месец",openPreviousView:"отвори претходен приказ",openNextView:"отвори следен приказ",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"годишен приказ, отвори календарски приказ":"календарски приказ, отвори годишен приказ",start:"Почеток",end:"Крај",cancelButtonLabel:"Откажи",clearButtonLabel:"Избриши",okButtonLabel:"OK",todayButtonLabel:"Денес",datePickerToolbarTitle:"Избери датум",dateTimePickerToolbarTitle:"Избери датум и време",timePickerToolbarTitle:"Избери време",dateRangePickerToolbarTitle:"Избери временски опсег",clockLabelText:(e,a,l)=>`Select ${e}. ${null===a?"Нема избрано време":`Избраното време е ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} часа`,minutesClockNumberText:e=>`${e} минути`,secondsClockNumberText:e=>`${e} секунди`,selectViewText:e=>`Избери ${e}`,calendarWeekNumberHeaderLabel:"Недела број",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Недела ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Избери датум, избраниот датум е ${a.format(e,"fullDate")}`:"Избери датум",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Избери време, избраното време е ${a.format(e,"fullTime")}`:"Избери време",fieldClearLabel:"Избриши",timeTableLabel:"одбери време",dateTableLabel:"одбери датум",fieldYearPlaceholder:e=>"Г".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"ДД",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"чч",fieldMinutesPlaceholder:()=>"мм",fieldSecondsPlaceholder:()=>"сс",fieldMeridiemPlaceholder:()=>"aa"}),Pe={hours:"timer",minutes:"minutter",seconds:"sekunder",meridiem:"meridiem"},ye={previousMonth:"Forrige måned",nextMonth:"Neste måned",openPreviousView:"åpne forrige visning",openNextView:"åpne neste visning",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"årsvisning er åpen, bytt til kalendervisning":"kalendervisning er åpen, bytt til årsvisning",start:"Start",end:"Slutt",cancelButtonLabel:"Avbryt",clearButtonLabel:"Fjern",okButtonLabel:"OK",todayButtonLabel:"I dag",datePickerToolbarTitle:"Velg dato",dateTimePickerToolbarTitle:"Velg dato & klokkeslett",timePickerToolbarTitle:"Velg klokkeslett",dateRangePickerToolbarTitle:"Velg datoperiode",clockLabelText:(e,a,l)=>`Velg ${Pe[e]}. ${null===a?"Ingen tid valgt":`Valgt tid er ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} timer`,minutesClockNumberText:e=>`${e} minutter`,secondsClockNumberText:e=>`${e} sekunder`,selectViewText:e=>`Velg ${Pe[e]}`,calendarWeekNumberHeaderLabel:"Ukenummer",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Uke ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Velg dato, valgt dato er ${a.format(e,"fullDate")}`:"Velg dato",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Velg tid, valgt tid er ${a.format(e,"fullTime")}`:"Velg tid",timeTableLabel:"velg tid",dateTableLabel:"velg dato",fieldYearPlaceholder:e=>"Å".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"tt",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},ge=(0,p.r)(ye),xe={hours:"uren",minutes:"minuten",seconds:"seconden",meridiem:"meridium"},ve={previousMonth:"Vorige maand",nextMonth:"Volgende maand",openPreviousView:"open vorige view",openNextView:"open volgende view",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"jaarweergave is geopend, schakel over naar kalenderweergave":"kalenderweergave is geopend, switch naar jaarweergave",start:"Start",end:"Einde",cancelButtonLabel:"Annuleren",clearButtonLabel:"Resetten",okButtonLabel:"OK",todayButtonLabel:"Vandaag",datePickerToolbarTitle:"Selecteer datum",dateTimePickerToolbarTitle:"Selecteer datum & tijd",timePickerToolbarTitle:"Selecteer tijd",dateRangePickerToolbarTitle:"Selecteer datumbereik",clockLabelText:(e,a,l)=>`Selecteer ${xe[e]}. ${null===a?"Geen tijd geselecteerd":`Geselecteerde tijd is ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} uren`,minutesClockNumberText:e=>`${e} minuten`,secondsClockNumberText:e=>`${e} seconden`,selectViewText:e=>`Selecteer ${xe[e]}`,calendarWeekNumberHeaderLabel:"Weeknummer",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Week ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Kies datum, geselecteerde datum is ${a.format(e,"fullDate")}`:"Kies datum",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Kies tijd, geselecteerde tijd is ${a.format(e,"fullTime")}`:"Kies tijd",timeTableLabel:"kies tijd",dateTableLabel:"kies datum",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Me=(0,p.r)(ve),Le={hours:"godzin",minutes:"minut",seconds:"sekund",meridiem:"popołudnie"},De={previousMonth:"Poprzedni miesiąc",nextMonth:"Następny miesiąc",openPreviousView:"otwórz poprzedni widok",openNextView:"otwórz następny widok",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"otwarty jest widok roku, przełącz na widok kalendarza":"otwarty jest widok kalendarza, przełącz na widok roku",start:"Początek",end:"Koniec",cancelButtonLabel:"Anuluj",clearButtonLabel:"Wyczyść",okButtonLabel:"Zatwierdź",todayButtonLabel:"Dzisiaj",datePickerToolbarTitle:"Wybierz datę",dateTimePickerToolbarTitle:"Wybierz datę i czas",timePickerToolbarTitle:"Wybierz czas",dateRangePickerToolbarTitle:"Wybierz zakres dat",clockLabelText:(e,a,l)=>`Wybierz ${Le[e]}. ${null===a?"Nie wybrano czasu":`Wybrany czas to ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} godzin`,minutesClockNumberText:e=>`${e} minut`,secondsClockNumberText:e=>`${e} sekund`,selectViewText:e=>`Wybierz ${Le[e]}`,calendarWeekNumberHeaderLabel:"Numer tygodnia",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Tydzień ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!=e&&a.isValid(e)?`Wybierz datę, obecnie wybrana data to ${a.format(e,"fullDate")}`:"Wybierz datę",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Wybierz czas, obecnie wybrany czas to ${a.format(e,"fullTime")}`:"Wybierz czas",timeTableLabel:"wybierz czas",dateTableLabel:"wybierz datę"},$e=(0,p.r)(De),we={hours:"horas",minutes:"minutos",seconds:"segundos",meridiem:"meridiano"},Ne={previousMonth:"Mês anterior",nextMonth:"Próximo mês",openPreviousView:"Abrir próxima seleção",openNextView:"Abrir seleção anterior",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"Seleção de ano está aberta, alternando para seleção de calendário":"Seleção de calendários está aberta, alternando para seleção de ano",start:"Início",end:"Fim",cancelButtonLabel:"Cancelar",clearButtonLabel:"Limpar",okButtonLabel:"OK",todayButtonLabel:"Hoje",datePickerToolbarTitle:"Selecione a data",dateTimePickerToolbarTitle:"Selecione data e hora",timePickerToolbarTitle:"Selecione a hora",dateRangePickerToolbarTitle:"Selecione o intervalo entre datas",clockLabelText:(e,a,l)=>`Selecione ${we[e]}. ${null===a?"Hora não selecionada":`Selecionado a hora ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} horas`,minutesClockNumberText:e=>`${e} minutos`,secondsClockNumberText:e=>`${e} segundos`,selectViewText:e=>`Selecione ${we[e]}`,calendarWeekNumberHeaderLabel:"Número da semana",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Semana ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Escolha uma data, data selecionada ${a.format(e,"fullDate")}`:"Escolha uma data",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Escolha uma hora, hora selecionada ${a.format(e,"fullTime")}`:"Escolha uma hora",timeTableLabel:"escolha uma hora",dateTableLabel:"escolha uma data",fieldYearPlaceholder:e=>"A".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"SSSS":"SS",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Ce=(0,p.r)(Ne),Ve={hours:"Ore",minutes:"Minute",seconds:"Secunde",meridiem:"Meridiane"},Ae={previousMonth:"Luna anterioară",nextMonth:"Luna următoare",openPreviousView:"Deschideți vizualizarea anterioară",openNextView:"Deschideți vizualizarea următoare",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"Vizualizarea anuală este deschisă, comutați la vizualizarea calendarului":"Vizualizarea calendarului este deschisă, comutați la vizualizarea anuală",start:"Început",end:"Sfârșit",cancelButtonLabel:"Anulare",clearButtonLabel:"Ștergere",okButtonLabel:"OK",todayButtonLabel:"Astăzi",datePickerToolbarTitle:"Selectați data",dateTimePickerToolbarTitle:"Selectați data și ora",timePickerToolbarTitle:"Selectați ora",dateRangePickerToolbarTitle:"Selectați intervalul de date",clockLabelText:(e,a,l)=>{var t;return`Selectați ${null!=(t=Ve[e])?t:e}. ${null===a?"Nicio oră selectată":`Ora selectată este ${l.format(a,"fullTime")}`}`},hoursClockNumberText:e=>`${e} ${Ve.hours}`,minutesClockNumberText:e=>`${e} ${Ve.minutes}`,secondsClockNumberText:e=>`${e}  ${Ve.seconds}`,selectViewText:e=>`Selectați ${Ve[e]}`,calendarWeekNumberHeaderLabel:"Număr săptămână",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Săptămâna ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Selectați data, data selectată este ${a.format(e,"fullDate")}`:"Selectați data",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Selectați ora, ora selectată este ${a.format(e,"fullTime")}`:"Selectați ora",fieldClearLabel:"Golire conținut",timeTableLabel:"Selectați ora",dateTableLabel:"Selectați data",fieldYearPlaceholder:e=>"A".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"LLLL":"LL",fieldDayPlaceholder:()=>"ZZ",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Se=(0,p.r)(Ae),We={hours:"часы",minutes:"минуты",seconds:"секунды",meridiem:"меридием"},Be={previousMonth:"Предыдущий месяц",nextMonth:"Следующий месяц",openPreviousView:"открыть предыдущий вид",openNextView:"открыть следующий вид",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"открыт годовой вид, переключить на календарный вид":"открыт календарный вид, переключить на годовой вид",start:"Начало",end:"Конец",cancelButtonLabel:"Отмена",clearButtonLabel:"Очистить",okButtonLabel:"Ок",todayButtonLabel:"Сегодня",datePickerToolbarTitle:"Выбрать дату",dateTimePickerToolbarTitle:"Выбрать дату и время",timePickerToolbarTitle:"Выбрать время",dateRangePickerToolbarTitle:"Выбрать период",clockLabelText:(e,a,l)=>`Выбрать ${We[e]}. ${null===a?"Время не выбрано":`Выбрано время ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} часов`,minutesClockNumberText:e=>`${e} минут`,secondsClockNumberText:e=>`${e} секунд`,selectViewText:e=>`Выбрать ${We[e]}`,calendarWeekNumberHeaderLabel:"Номер недели",calendarWeekNumberHeaderText:"№",calendarWeekNumberAriaLabelText:e=>`Неделя ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Выберите дату, выбрана дата ${a.format(e,"fullDate")}`:"Выберите дату",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Выберите время, выбрано время ${a.format(e,"fullTime")}`:"Выберите время",fieldClearLabel:"Очистить значение",timeTableLabel:"выбрать время",dateTableLabel:"выбрать дату",fieldYearPlaceholder:e=>"Г".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"ММММ":"ММ",fieldDayPlaceholder:()=>"ДД",fieldHoursPlaceholder:()=>"чч",fieldMinutesPlaceholder:()=>"мм",fieldSecondsPlaceholder:()=>"сс",fieldMeridiemPlaceholder:()=>"(д|п)п"},Re=(0,p.r)(Be),ze={hours:"Hodiny",minutes:"Minúty",seconds:"Sekundy",meridiem:"Popoludnie"},Oe={previousMonth:"Ďalší mesiac",nextMonth:"Predchádzajúci mesiac",openPreviousView:"otvoriť predchádzajúce zobrazenie",openNextView:"otvoriť ďalšie zobrazenie",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"ročné zobrazenie otvorené, prepnite do zobrazenia kalendára":"zobrazenie kalendára otvorené, prepnite do zobrazenia roka",start:"Začiatok",end:"Koniec",cancelButtonLabel:"Zrušiť",clearButtonLabel:"Vymazať",okButtonLabel:"Potvrdiť",todayButtonLabel:"Dnes",datePickerToolbarTitle:"Vyberte dátum",dateTimePickerToolbarTitle:"Vyberte dátum a čas",timePickerToolbarTitle:"Vyberte čas",dateRangePickerToolbarTitle:"Vyberete rozmedzie dátumov",clockLabelText:(e,a,l)=>{var t;return`${null!=(t=ze[e])?t:e} vybraný. ${null===a?"Nie je vybraný čas":`Vybraný čas je ${l.format(a,"fullTime")}`}`},hoursClockNumberText:e=>`${e} hodín`,minutesClockNumberText:e=>`${e} minút`,secondsClockNumberText:e=>`${e} sekúnd`,selectViewText:e=>`Vyberte ${ze[e]}`,calendarWeekNumberHeaderLabel:"Týždeň v roku",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`${e} týždeň v roku`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Vyberte dátum, vybraný dátum je ${a.format(e,"fullDate")}`:"Vyberte dátum",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Vyberte čas, vybraný čas je ${a.format(e,"fullTime")}`:"Vyberte čas",timeTableLabel:"vyberte čas",dateTableLabel:"vyberte dátum",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Ee=(0,p.r)(Oe),je={hours:"timmar",minutes:"minuter",seconds:"sekunder",meridiem:"meridiem"},He={previousMonth:"Föregående månad",nextMonth:"Nästa månad",openPreviousView:"öppna föregående vy",openNextView:"öppna nästa vy",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"årsvyn är öppen, byt till kalendervy":"kalendervyn är öppen, byt till årsvy",start:"Start",end:"Slut",cancelButtonLabel:"Avbryt",clearButtonLabel:"Rensa",okButtonLabel:"OK",todayButtonLabel:"Idag",datePickerToolbarTitle:"Välj datum",dateTimePickerToolbarTitle:"Välj datum & tid",timePickerToolbarTitle:"Välj tid",dateRangePickerToolbarTitle:"Välj datumintervall",clockLabelText:(e,a,l)=>`Välj ${je[e]}. ${null===a?"Ingen tid vald":`Vald tid är ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} timmar`,minutesClockNumberText:e=>`${e} minuter`,secondsClockNumberText:e=>`${e} sekunder`,selectViewText:e=>`Välj ${je[e]}`,calendarWeekNumberHeaderLabel:"Vecka nummer",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Vecka ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Välj datum, valt datum är ${a.format(e,"fullDate")}`:"Välj datum",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Välj tid, vald tid är ${a.format(e,"fullTime")}`:"Välj tid",timeTableLabel:"välj tid",dateTableLabel:"välj datum"},Ie=(0,p.r)(He),Fe={hours:"saat",minutes:"dakika",seconds:"saniye",meridiem:"öğleden sonra"},Ye={previousMonth:"Önceki ay",nextMonth:"Sonraki ay",openPreviousView:"sonraki görünüm",openNextView:"önceki görünüm",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"yıl görünümü açık, takvim görünümüne geç":"takvim görünümü açık, yıl görünümüne geç",start:"Başlangıç",end:"Bitiş",cancelButtonLabel:"iptal",clearButtonLabel:"Temizle",okButtonLabel:"Tamam",todayButtonLabel:"Bugün",datePickerToolbarTitle:"Tarih Seç",dateTimePickerToolbarTitle:"Tarih & Saat seç",timePickerToolbarTitle:"Saat seç",dateRangePickerToolbarTitle:"Tarih aralığı seçin",clockLabelText:(e,a,l)=>`${Fe[e]} seç.  ${null===a?"Zaman seçilmedi":`Seçilen zaman: ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} saat`,minutesClockNumberText:e=>`${e} dakika`,secondsClockNumberText:e=>`${e} saniye`,selectViewText:e=>`Seç ${Fe[e]}`,calendarWeekNumberHeaderLabel:"Hafta numarası",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Hafta ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Tarih seçin, seçilen tarih: ${a.format(e,"fullDate")}`:"Tarih seç",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Saat seçin, seçilen saat: ${a.format(e,"fullTime")}`:"Saat seç",timeTableLabel:"saat seç",dateTableLabel:"tarih seç",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"AAA":"AA",fieldDayPlaceholder:()=>"GG",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"HHH":"HH",fieldHoursPlaceholder:()=>"ss",fieldMinutesPlaceholder:()=>"dd",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Ke=(0,p.r)(Ye),Ue={hours:"годин",minutes:"хвилин",seconds:"секунд",meridiem:"Південь"},qe={previousMonth:"Попередній місяць",nextMonth:"Наступний місяць",openPreviousView:"відкрити попередній вигляд",openNextView:"відкрити наступний вигляд",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"річний вигляд відкрито, перейти до календарного вигляду":"календарний вигляд відкрито, перейти до річного вигляду",start:"Початок",end:"Кінець",cancelButtonLabel:"Відміна",clearButtonLabel:"Очистити",okButtonLabel:"OK",todayButtonLabel:"Сьогодні",datePickerToolbarTitle:"Вибрати дату",dateTimePickerToolbarTitle:"Вибрати дату і час",timePickerToolbarTitle:"Вибрати час",dateRangePickerToolbarTitle:"Вибрати календарний період",clockLabelText:(e,a,l)=>`Вибрати ${Ue[e]}. ${null===a?"Час не вибраний":`Вибрано час ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} годин`,minutesClockNumberText:e=>`${e} хвилин`,secondsClockNumberText:e=>`${e} секунд`,selectViewText:e=>`Вибрати ${Ue[e]}`,calendarWeekNumberHeaderLabel:"Номер тижня",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Тиждень ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Оберіть дату, обрана дата  ${a.format(e,"fullDate")}`:"Оберіть дату",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Оберіть час, обраний час  ${a.format(e,"fullTime")}`:"Оберіть час",timeTableLabel:"оберіть час",dateTableLabel:"оберіть дату",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},Ze=(0,p.r)(qe),Xe={hours:"گھنٹے",minutes:"منٹ",seconds:"سیکنڈ",meridiem:"میریڈیم"},_e={previousMonth:"پچھلا مہینہ",nextMonth:"اگلا مہینہ",openPreviousView:"پچھلا ویو کھولیں",openNextView:"اگلا ویو کھولیں",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"سال والا ویو کھلا ہے۔ کیلنڈر والا ویو کھولیں":"کیلنڈر والا ویو کھلا ہے۔ سال والا ویو کھولیں",start:"شروع",end:"ختم",cancelButtonLabel:"کینسل",clearButtonLabel:"کلئیر",okButtonLabel:"اوکے",todayButtonLabel:"آج",datePickerToolbarTitle:"تاریخ منتخب کریں",dateTimePickerToolbarTitle:"تاریخ اور وقت منتخب کریں",timePickerToolbarTitle:"وقت منتخب کریں",dateRangePickerToolbarTitle:"تاریخوں کی رینج منتخب کریں",clockLabelText:(e,a,l)=>`${Xe[e]} منتخب کریں ${null===a?"کوئی وقت منتخب نہیں":`منتخب وقت ہے ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} گھنٹے`,minutesClockNumberText:e=>`${e} منٹ`,secondsClockNumberText:e=>`${e} سیکنڈ`,selectViewText:e=>`${Xe[e]} منتخب کریں`,calendarWeekNumberHeaderLabel:"ہفتہ نمبر",calendarWeekNumberHeaderText:"نمبر",calendarWeekNumberAriaLabelText:e=>`ہفتہ ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`تاریخ منتخب کریں، منتخب شدہ تاریخ ہے ${a.format(e,"fullDate")}`:"تاریخ منتخب کریں",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`وقت منتخب کریں، منتخب شدہ وقت ہے ${a.format(e,"fullTime")}`:"وقت منتخب کریں",timeTableLabel:"وقت منتخب کریں",dateTableLabel:"تاریخ منتخب کریں"},Ge=(0,p.r)(_e),Je={hours:"giờ",minutes:"phút",seconds:"giây",meridiem:"buổi"},Qe={previousMonth:"Tháng trước",nextMonth:"Tháng sau",openPreviousView:"mở xem trước",openNextView:"mở xem sau",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"đang mở xem năm, chuyển sang xem lịch":"đang mở xem lịch, chuyển sang xem năm",start:"Bắt đầu",end:"Kết thúc",cancelButtonLabel:"Hủy",clearButtonLabel:"Xóa",okButtonLabel:"OK",todayButtonLabel:"Hôm nay",datePickerToolbarTitle:"Chọn ngày",dateTimePickerToolbarTitle:"Chọn ngày và giờ",timePickerToolbarTitle:"Chọn giờ",dateRangePickerToolbarTitle:"Chọn khoảng ngày",clockLabelText:(e,a,l)=>`Chọn ${Je[e]}. ${null===a?"Không có giờ được chọn":`Giờ được chọn là ${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e} giờ`,minutesClockNumberText:e=>`${e} phút`,secondsClockNumberText:e=>`${e} giây`,selectViewText:e=>`Chọn ${Je[e]}`,calendarWeekNumberHeaderLabel:"Số tuần",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`Tuần ${e}`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Chọn ngày, ngày đã chọn là ${a.format(e,"fullDate")}`:"Chọn ngày",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`Chọn giờ, giờ đã chọn là ${a.format(e,"fullTime")}`:"Chọn giờ",timeTableLabel:"chọn giờ",dateTableLabel:"chọn ngày",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},ea=(0,p.r)(Qe),aa={hours:"小时",minutes:"分钟",seconds:"秒",meridiem:"十二小时制"},la={previousMonth:"上个月",nextMonth:"下个月",openPreviousView:"前一个视图",openNextView:"下一个视图",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"年视图已打开，切换为日历视图":"日历视图已打开，切换为年视图",start:"开始",end:"结束",cancelButtonLabel:"取消",clearButtonLabel:"清除",okButtonLabel:"确认",todayButtonLabel:"今天",datePickerToolbarTitle:"选择日期",dateTimePickerToolbarTitle:"选择日期和时间",timePickerToolbarTitle:"选择时间",dateRangePickerToolbarTitle:"选择时间范围",clockLabelText:(e,a,l)=>`选择 ${aa[e]}. ${null===a?"未选择时间":`已选择${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e}小时`,minutesClockNumberText:e=>`${e}分钟`,secondsClockNumberText:e=>`${e}秒`,selectViewText:e=>`选择 ${aa[e]}`,calendarWeekNumberHeaderLabel:"周数",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`第${e}周`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`选择日期，已选择${a.format(e,"fullDate")}`:"选择日期",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`选择时间，已选择${a.format(e,"fullTime")}`:"选择时间",fieldClearLabel:"清除",timeTableLabel:"选择时间",dateTableLabel:"选择日期",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},ta=(0,p.r)(la),oa={hours:"小時",minutes:"分鐘",seconds:"秒",meridiem:"子午線"},ra={previousMonth:"上個月",nextMonth:"下個月",openPreviousView:"前一個檢視表",openNextView:"下一個檢視表",calendarViewSwitchingButtonAriaLabel:e=>"year"===e?"年份檢視表已打開，切換以檢視日曆":"日曆檢視表已打開，切換以檢視年份",start:"開始",end:"結束",cancelButtonLabel:"取消",clearButtonLabel:"清除",okButtonLabel:"確認",todayButtonLabel:"今日",datePickerToolbarTitle:"選擇日期",dateTimePickerToolbarTitle:"選擇日期和時間",timePickerToolbarTitle:"選擇時間",dateRangePickerToolbarTitle:"選擇時間範圍",clockLabelText:(e,a,l)=>`選擇 ${oa[e]}. ${null===a?"未選擇時間":`已選擇${l.format(a,"fullTime")}`}`,hoursClockNumberText:e=>`${e}小時`,minutesClockNumberText:e=>`${e}分鐘`,secondsClockNumberText:e=>`${e}秒`,selectViewText:e=>`選擇 ${oa[e]}`,calendarWeekNumberHeaderLabel:"週數",calendarWeekNumberHeaderText:"#",calendarWeekNumberAriaLabelText:e=>`第${e}週`,calendarWeekNumberText:e=>`${e}`,openDatePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`選擇日期，已選擇${a.format(e,"fullDate")}`:"選擇日期",openTimePickerDialogue:(e,a)=>null!==e&&a.isValid(e)?`選擇時間，已選擇${a.format(e,"fullTime")}`:"選擇時間",timeTableLabel:"選擇時間",dateTableLabel:"選擇日期",fieldYearPlaceholder:e=>"Y".repeat(e.digitAmount),fieldMonthPlaceholder:e=>"letter"===e.contentType?"MMMM":"MM",fieldDayPlaceholder:()=>"DD",fieldWeekDayPlaceholder:e=>"letter"===e.contentType?"EEEE":"EE",fieldHoursPlaceholder:()=>"hh",fieldMinutesPlaceholder:()=>"mm",fieldSecondsPlaceholder:()=>"ss",fieldMeridiemPlaceholder:()=>"aa"},ia=(0,p.r)(ra);var na=l(55285),sa=l(40644),da=l(93345),ua=l(1043),ca=l(3541),ma=l(71611),ba=l(16566),Ta=l(32820),ha=l(64741),pa=l(23887),ka=l(51468),fa=l(54274);const Pa=({props:e,inputRef:a})=>{const l=(e=>{var a,l,t;const o=(0,ka.hc)(),r=(0,ka.Yg)();return(0,na.A)({},e,{disablePast:null!=(a=e.disablePast)&&a,disableFuture:null!=(l=e.disableFuture)&&l,format:null!=(t=e.format)?t:o.formats.keyboardDate,minDate:(0,pa.IP)(o,e.minDate,r.minDate),maxDate:(0,pa.IP)(o,e.maxDate,r.maxDate)})})(e),{forwardedProps:t,internalProps:o}=(0,fa.D)(l,"date");return(0,Ta.M)({inputRef:a,forwardedProps:t,internalProps:o,valueManager:ba.W,fieldValueManager:ba.o,validator:ha.Z,valueType:"date"})};var ya=l(57655),ga=l(74848);const xa=["components","componentsProps","slots","slotProps","InputProps","inputProps"],va=["inputRef"],Ma=["ref","onPaste","onKeyDown","inputMode","readOnly","clearable","onClear"],La=da.forwardRef((function(e,a){var l,t,o;const r=(0,ca.A)({props:e,name:"MuiDateField"}),{components:i,componentsProps:n,slots:s,slotProps:d,InputProps:u,inputProps:c}=r,m=(0,sa.A)(r,xa),b=r,T=null!=(l=null!=(t=null==s?void 0:s.textField)?t:null==i?void 0:i.TextField)?l:ua.A,h=(0,ma.Q)({elementType:T,externalSlotProps:null!=(o=null==d?void 0:d.textField)?o:null==n?void 0:n.textField,externalForwardedProps:m,ownerState:b}),{inputRef:p}=h,k=(0,sa.A)(h,va);k.inputProps=(0,na.A)({},c,k.inputProps),k.InputProps=(0,na.A)({},u,k.InputProps);const f=Pa({props:k,inputRef:p}),{ref:P,onPaste:y,onKeyDown:g,inputMode:x,readOnly:v,clearable:M,onClear:L}=f,D=(0,sa.A)(f,Ma),{InputProps:$,fieldProps:w}=(0,ya.Z)({onClear:L,clearable:M,fieldProps:D,InputProps:D.InputProps,slots:s,slotProps:d,components:i,componentsProps:n});return(0,ga.jsx)(T,(0,na.A)({ref:a},w,{InputProps:(0,na.A)({},$,{readOnly:v}),inputProps:(0,na.A)({},D.inputProps,{inputMode:x,onPaste:y,onKeyDown:g,ref:P})}))}));var Da=l(71724);const $a=({props:e,inputRef:a})=>{const l=(e=>{var a,l,t,o;const r=(0,ka.hc)(),i=(null!=(a=e.ampm)?a:r.is12HourCycleInCurrentLocale())?r.formats.fullTime12h:r.formats.fullTime24h;return(0,na.A)({},e,{disablePast:null!=(l=e.disablePast)&&l,disableFuture:null!=(t=e.disableFuture)&&t,format:null!=(o=e.format)?o:i})})(e),{forwardedProps:t,internalProps:o}=(0,fa.D)(l,"time");return(0,Ta.M)({inputRef:a,forwardedProps:t,internalProps:o,valueManager:ba.W,fieldValueManager:ba.o,validator:Da.i,valueType:"time"})},wa=["slots","slotProps","components","componentsProps","InputProps","inputProps"],Na=["inputRef"],Ca=["ref","onPaste","onKeyDown","inputMode","readOnly","clearable","onClear"],Va=da.forwardRef((function(e,a){var l,t,o;const r=(0,ca.A)({props:e,name:"MuiTimeField"}),{slots:i,slotProps:n,components:s,componentsProps:d,InputProps:u,inputProps:c}=r,m=(0,sa.A)(r,wa),b=r,T=null!=(l=null!=(t=null==i?void 0:i.textField)?t:null==s?void 0:s.TextField)?l:ua.A,h=(0,ma.Q)({elementType:T,externalSlotProps:null!=(o=null==n?void 0:n.textField)?o:null==d?void 0:d.textField,externalForwardedProps:m,ownerState:b}),{inputRef:p}=h,k=(0,sa.A)(h,Na);k.inputProps=(0,na.A)({},c,k.inputProps),k.InputProps=(0,na.A)({},u,k.InputProps);const f=$a({props:k,inputRef:p}),{ref:P,onPaste:y,onKeyDown:g,inputMode:x,readOnly:v,clearable:M,onClear:L}=f,D=(0,sa.A)(f,Ca),{InputProps:$,fieldProps:w}=(0,ya.Z)({onClear:L,clearable:M,fieldProps:D,InputProps:D.InputProps,slots:i,slotProps:n,components:s,componentsProps:d});return(0,ga.jsx)(T,(0,na.A)({ref:a},w,{InputProps:(0,na.A)({},$,{readOnly:v}),inputProps:(0,na.A)({},D.inputProps,{inputMode:x,onPaste:y,onKeyDown:g,ref:P})}))}));var Aa=l(62251),Sa=l(27176),Wa=l(27364),Ba=l(91645),Ra=l(18247),za=l(45908),Oa=l(35790),Ea=l(80199),ja=l(43059),Ha=l(4627),Ia=l(60839),Fa=l(51914),Ya=l(27228),Ka=l(48443),Ua=l(66986),qa=l(5556),Za=l.n(qa),Xa=l(28919),_a=l(47035),Ga=l(11848),Ja=l(64111),Qa=l(31886),el=l(17245),al=l(27553);const ll=e=>(0,el.Ay)("MuiDayCalendarSkeleton",e),tl=(0,al.A)("MuiDayCalendarSkeleton",["root","week","daySkeleton"]),ol=["className"],rl=e=>{const{classes:a}=e;return(0,Ja.A)({root:["root"],week:["week"],daySkeleton:["daySkeleton"]},ll,a)},il=(0,Ga.Ay)("div",{name:"MuiDayCalendarSkeleton",slot:"Root",overridesResolver:(e,a)=>a.root})({alignSelf:"start"}),nl=(0,Ga.Ay)("div",{name:"MuiDayCalendarSkeleton",slot:"Week",overridesResolver:(e,a)=>a.week})({margin:`${Qa.y0}px 0`,display:"flex",justifyContent:"center"}),sl=(0,Ga.Ay)(_a.A,{name:"MuiDayCalendarSkeleton",slot:"DaySkeleton",overridesResolver:(e,a)=>a.daySkeleton})((({ownerState:e})=>(0,na.A)({margin:`0 ${Qa.y0}px`},0===e.day&&{visibility:"hidden"})));sl.propTypes={ownerState:Za().shape({day:Za().number.isRequired}).isRequired};const dl=[[0,1,1,1,1,1,1],[1,1,1,1,1,1,1],[1,1,1,1,1,1,1],[1,1,1,1,1,1,1],[1,1,1,1,0,0,0]];function ul(e){const a=(0,ca.A)({props:e,name:"MuiDayCalendarSkeleton"}),{className:l}=a,t=(0,sa.A)(a,ol),o=rl(t);return(0,ga.jsx)(il,(0,na.A)({className:(0,Xa.A)(o.root,l)},t,{children:dl.map(((e,a)=>(0,ga.jsx)(nl,{className:o.week,children:e.map(((e,a)=>(0,ga.jsx)(sl,{variant:"circular",width:Qa.B3,height:Qa.B3,className:o.daySkeleton,ownerState:{day:e}},a)))},a)))}))}var cl=l(15327),ml=l(45489),bl=l(38721),Tl=l(34469),hl=l(33551),pl=l(6498);function kl(e){return(0,el.Ay)("MuiDatePickerToolbar",e)}const fl=(0,al.A)("MuiDatePickerToolbar",["root","title"]),Pl=["value","isLandscape","onChange","toolbarFormat","toolbarPlaceholder","views","className"],yl=(0,Ga.Ay)(pl.Z,{name:"MuiDatePickerToolbar",slot:"Root",overridesResolver:(e,a)=>a.root})({}),gl=(0,Ga.Ay)(hl.A,{name:"MuiDatePickerToolbar",slot:"Title",overridesResolver:(e,a)=>a.title})((({ownerState:e})=>(0,na.A)({},e.isLandscape&&{margin:"auto 16px auto auto"}))),xl=da.forwardRef((function(e,a){const l=(0,ca.A)({props:e,name:"MuiDatePickerToolbar"}),{value:t,isLandscape:o,toolbarFormat:r,toolbarPlaceholder:i="––",views:n,className:s}=l,d=(0,sa.A)(l,Pl),u=(0,ka.hc)(),c=(0,ka.Nq)(),m=(e=>{const{classes:a}=e;return(0,Ja.A)({root:["root"],title:["title"]},kl,a)})(l),b=da.useMemo((()=>{if(!t)return i;const e=(0,pa.Wq)(u,{format:r,views:n},!0);return u.formatByString(t,e)}),[t,r,i,u,n]),T=l;return(0,ga.jsx)(yl,(0,na.A)({ref:a,toolbarTitle:c.datePickerToolbarTitle,isLandscape:o,className:(0,Xa.A)(m.root,s)},d,{children:(0,ga.jsx)(gl,{variant:"h4",align:o?"left":"center",ownerState:T,className:m.title,children:b})}))}));var vl=l(60831);function Ml(e,a){var l,t,o,r;const i=(0,ka.hc)(),n=(0,ka.Yg)(),s=(0,ca.A)({props:e,name:a}),d=da.useMemo((()=>{var e;return null==(null==(e=s.localeText)?void 0:e.toolbarTitle)?s.localeText:(0,na.A)({},s.localeText,{datePickerToolbarTitle:s.localeText.toolbarTitle})}),[s.localeText]),u=null!=(l=s.slots)?l:(0,vl.p)(s.components);return(0,na.A)({},s,{localeText:d},(0,Tl.R)({views:s.views,openTo:s.openTo,defaultViews:["year","day"],defaultOpenTo:"day"}),{disableFuture:null!=(t=s.disableFuture)&&t,disablePast:null!=(o=s.disablePast)&&o,minDate:(0,pa.IP)(i,s.minDate,n.minDate),maxDate:(0,pa.IP)(i,s.maxDate,n.maxDate),slots:(0,na.A)({toolbar:xl},u),slotProps:null!=(r=s.slotProps)?r:s.componentsProps})}var Ll=l(80954),Dl=l(40293),$l=l(62067),wl=l(37755);const Nl=da.forwardRef((function(e,a){var l,t,o,r;const i=(0,ka.Nq)(),n=(0,ka.hc)(),s=Ml(e,"MuiDesktopDatePicker"),d=(0,na.A)({day:wl.W,month:wl.W,year:wl.W},s.viewRenderers),u=(0,na.A)({},s,{viewRenderers:d,format:(0,pa.Wq)(n,s,!1),yearsPerRow:null!=(l=s.yearsPerRow)?l:4,slots:(0,na.A)({openPickerIcon:Dl.CT,field:La},s.slots),slotProps:(0,na.A)({},s.slotProps,{field:e=>{var l;return(0,na.A)({},(0,ml.Y)(null==(l=s.slotProps)?void 0:l.field,e),(0,$l.zd)(s),{ref:a})},toolbar:(0,na.A)({hidden:!0},null==(t=s.slotProps)?void 0:t.toolbar)})}),{renderPicker:c}=(0,Ll.U)({props:u,valueManager:ba.W,valueType:"date",getOpenDialogAriaText:null!=(o=null==(r=u.localeText)?void 0:r.openDatePickerDialogue)?o:i.openDatePickerDialogue,validator:ha.Z});return c()}));Nl.propTypes={autoFocus:Za().bool,className:Za().string,closeOnSelect:Za().bool,components:Za().object,componentsProps:Za().object,dayOfWeekFormatter:Za().func,defaultCalendarMonth:Za().any,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableHighlightToday:Za().bool,disableOpenPicker:Za().bool,disablePast:Za().bool,displayWeekNumber:Za().bool,fixedWeekNumber:Za().number,format:Za().string,formatDensity:Za().oneOf(["dense","spacious"]),inputRef:bl.A,label:Za().node,loading:Za().bool,localeText:Za().object,maxDate:Za().any,minDate:Za().any,monthsPerRow:Za().oneOf([3,4]),name:Za().string,onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onMonthChange:Za().func,onOpen:Za().func,onSelectedSectionsChange:Za().func,onViewChange:Za().func,onYearChange:Za().func,open:Za().bool,openTo:Za().oneOf(["day","month","year"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,renderLoading:Za().func,selectedSections:Za().oneOfType([Za().oneOf(["all","day","hours","meridiem","minutes","month","seconds","weekDay","year"]),Za().number,Za().shape({endIndex:Za().number.isRequired,startIndex:Za().number.isRequired})]),shouldDisableDate:Za().func,shouldDisableMonth:Za().func,shouldDisableYear:Za().func,showDaysOutsideCurrentMonth:Za().bool,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),timezone:Za().string,value:Za().any,view:Za().oneOf(["day","month","year"]),viewRenderers:Za().shape({day:Za().func,month:Za().func,year:Za().func}),views:Za().arrayOf(Za().oneOf(["day","month","year"]).isRequired),yearsPerRow:Za().oneOf([3,4])};var Cl=l(8078);const Vl=da.forwardRef((function(e,a){var l,t,o;const r=(0,ka.Nq)(),i=(0,ka.hc)(),n=Ml(e,"MuiMobileDatePicker"),s=(0,na.A)({day:wl.W,month:wl.W,year:wl.W},n.viewRenderers),d=(0,na.A)({},n,{viewRenderers:s,format:(0,pa.Wq)(i,n,!1),slots:(0,na.A)({field:La},n.slots),slotProps:(0,na.A)({},n.slotProps,{field:e=>{var l;return(0,na.A)({},(0,ml.Y)(null==(l=n.slotProps)?void 0:l.field,e),(0,$l.zd)(n),{ref:a})},toolbar:(0,na.A)({hidden:!1},null==(l=n.slotProps)?void 0:l.toolbar)})}),{renderPicker:u}=(0,Cl.C)({props:d,valueManager:ba.W,valueType:"date",getOpenDialogAriaText:null!=(t=null==(o=d.localeText)?void 0:o.openDatePickerDialogue)?t:r.openDatePickerDialogue,validator:ha.Z});return u()}));Vl.propTypes={autoFocus:Za().bool,className:Za().string,closeOnSelect:Za().bool,components:Za().object,componentsProps:Za().object,dayOfWeekFormatter:Za().func,defaultCalendarMonth:Za().any,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableHighlightToday:Za().bool,disableOpenPicker:Za().bool,disablePast:Za().bool,displayWeekNumber:Za().bool,fixedWeekNumber:Za().number,format:Za().string,formatDensity:Za().oneOf(["dense","spacious"]),inputRef:bl.A,label:Za().node,loading:Za().bool,localeText:Za().object,maxDate:Za().any,minDate:Za().any,monthsPerRow:Za().oneOf([3,4]),name:Za().string,onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onMonthChange:Za().func,onOpen:Za().func,onSelectedSectionsChange:Za().func,onViewChange:Za().func,onYearChange:Za().func,open:Za().bool,openTo:Za().oneOf(["day","month","year"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,renderLoading:Za().func,selectedSections:Za().oneOfType([Za().oneOf(["all","day","hours","meridiem","minutes","month","seconds","weekDay","year"]),Za().number,Za().shape({endIndex:Za().number.isRequired,startIndex:Za().number.isRequired})]),shouldDisableDate:Za().func,shouldDisableMonth:Za().func,shouldDisableYear:Za().func,showDaysOutsideCurrentMonth:Za().bool,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),timezone:Za().string,value:Za().any,view:Za().oneOf(["day","month","year"]),viewRenderers:Za().shape({day:Za().func,month:Za().func,year:Za().func}),views:Za().arrayOf(Za().oneOf(["day","month","year"]).isRequired),yearsPerRow:Za().oneOf([3,4])};var Al=l(24034);const Sl=["desktopModeMediaQuery"],Wl=da.forwardRef((function(e,a){const l=(0,ca.A)({props:e,name:"MuiDatePicker"}),{desktopModeMediaQuery:t=Al.jX}=l,o=(0,sa.A)(l,Sl);return(0,cl.A)(t,{defaultMatches:!0})?(0,ga.jsx)(Nl,(0,na.A)({ref:a},o)):(0,ga.jsx)(Vl,(0,na.A)({ref:a},o))}));var Bl=l(72763),Rl=l(631);const zl=["props","ref"],Ol=(0,Ga.Ay)(Rl.CJ)((({theme:e})=>({overflow:"hidden",minWidth:Qa.eX,backgroundColor:(e.vars||e).palette.background.paper}))),El=e=>{var a;let{props:l,ref:t}=e,o=(0,sa.A)(e,zl);const{localeText:r,slots:i,slotProps:n,className:s,sx:d,displayStaticWrapperAs:u,autoFocus:c}=l,{layoutProps:m,renderCurrentView:T}=(0,Bl.k)((0,na.A)({},o,{props:l,autoFocusView:null!=c&&c,additionalViewProps:{},wrapperVariant:u})),h=null!=(a=null==i?void 0:i.layout)?a:Ol;return{renderPicker:()=>{var e,a,l;return(0,ga.jsx)(b.$,{localeText:r,children:(0,ga.jsx)(h,(0,na.A)({},m,null==n?void 0:n.layout,{slots:i,slotProps:n,sx:[...Array.isArray(d)?d:[d],...Array.isArray(null==n||null==(e=n.layout)?void 0:e.sx)?n.layout.sx:[null==n||null==(a=n.layout)?void 0:a.sx]],className:(0,Xa.A)(s,null==n||null==(l=n.layout)?void 0:l.className),ref:t,children:T()}))})}}},jl=da.forwardRef((function(e,a){var l,t,o;const r=Ml(e,"MuiStaticDatePicker"),i=null!=(l=r.displayStaticWrapperAs)?l:"mobile",n=(0,na.A)({day:wl.W,month:wl.W,year:wl.W},r.viewRenderers),s=(0,na.A)({},r,{viewRenderers:n,displayStaticWrapperAs:i,yearsPerRow:null!=(t=r.yearsPerRow)?t:"mobile"===i?3:4,slotProps:(0,na.A)({},r.slotProps,{toolbar:(0,na.A)({hidden:"desktop"===i},null==(o=r.slotProps)?void 0:o.toolbar)})}),{renderPicker:d}=El({props:s,valueManager:ba.W,valueType:"date",validator:ha.Z,ref:a});return d()}));jl.propTypes={autoFocus:Za().bool,className:Za().string,components:Za().object,componentsProps:Za().object,dayOfWeekFormatter:Za().func,defaultCalendarMonth:Za().any,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableHighlightToday:Za().bool,disablePast:Za().bool,displayStaticWrapperAs:Za().oneOf(["desktop","mobile"]),displayWeekNumber:Za().bool,fixedWeekNumber:Za().number,loading:Za().bool,localeText:Za().object,maxDate:Za().any,minDate:Za().any,monthsPerRow:Za().oneOf([3,4]),onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onMonthChange:Za().func,onViewChange:Za().func,onYearChange:Za().func,openTo:Za().oneOf(["day","month","year"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,renderLoading:Za().func,shouldDisableDate:Za().func,shouldDisableMonth:Za().func,shouldDisableYear:Za().func,showDaysOutsideCurrentMonth:Za().bool,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),timezone:Za().string,value:Za().any,view:Za().oneOf(["day","month","year"]),viewRenderers:Za().shape({day:Za().func,month:Za().func,year:Za().func}),views:Za().arrayOf(Za().oneOf(["day","month","year"]).isRequired),yearsPerRow:Za().oneOf([3,4])};var Hl=l(44675),Il=l(96166),Fl=l(8934),Yl=l(50117);function Kl(e){return(0,el.Ay)("MuiTimePickerToolbar",e)}const Ul=(0,al.A)("MuiTimePickerToolbar",["root","separator","hourMinuteLabel","hourMinuteLabelLandscape","hourMinuteLabelReverse","ampmSelection","ampmLandscape","ampmLabel"]),ql=["ampm","ampmInClock","value","isLandscape","onChange","view","onViewChange","views","disabled","readOnly","className"],Zl=e=>{const{theme:a,isLandscape:l,classes:t}=e,o={root:["root"],separator:["separator"],hourMinuteLabel:["hourMinuteLabel",l&&"hourMinuteLabelLandscape","rtl"===a.direction&&"hourMinuteLabelReverse"],ampmSelection:["ampmSelection",l&&"ampmLandscape"],ampmLabel:["ampmLabel"]};return(0,Ja.A)(o,Kl,t)},Xl=(0,Ga.Ay)(pl.Z,{name:"MuiTimePickerToolbar",slot:"Root",overridesResolver:(e,a)=>a.root})({}),_l=(0,Ga.Ay)(Il.k,{name:"MuiTimePickerToolbar",slot:"Separator",overridesResolver:(e,a)=>a.separator})({outline:0,margin:"0 4px 0 2px",cursor:"default"}),Gl=(0,Ga.Ay)("div",{name:"MuiTimePickerToolbar",slot:"HourMinuteLabel",overridesResolver:(e,a)=>[{[`&.${Ul.hourMinuteLabelLandscape}`]:a.hourMinuteLabelLandscape,[`&.${Ul.hourMinuteLabelReverse}`]:a.hourMinuteLabelReverse},a.hourMinuteLabel]})((({theme:e,ownerState:a})=>(0,na.A)({display:"flex",justifyContent:"flex-end",alignItems:"flex-end"},a.isLandscape&&{marginTop:"auto"},"rtl"===e.direction&&{flexDirection:"row-reverse"})));Gl.propTypes={as:Za().elementType,ownerState:Za().object.isRequired,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object])};const Jl=(0,Ga.Ay)("div",{name:"MuiTimePickerToolbar",slot:"AmPmSelection",overridesResolver:(e,a)=>[{[`.${Ul.ampmLabel}`]:a.ampmLabel},{[`&.${Ul.ampmLandscape}`]:a.ampmLandscape},a.ampmSelection]})((({ownerState:e})=>(0,na.A)({display:"flex",flexDirection:"column",marginRight:"auto",marginLeft:12},e.isLandscape&&{margin:"4px 0 auto",flexDirection:"row",justifyContent:"space-around",flexBasis:"100%"},{[`& .${Ul.ampmLabel}`]:{fontSize:17}})));function Ql(e){const a=(0,ca.A)({props:e,name:"MuiTimePickerToolbar"}),{ampm:l,ampmInClock:t,value:o,isLandscape:r,onChange:i,view:n,onViewChange:s,views:d,disabled:u,readOnly:c,className:m}=a,b=(0,sa.A)(a,ql),T=(0,ka.hc)(),h=(0,ka.Nq)(),p=(0,Hl.A)(),k=Boolean(l&&!t&&d.includes("hours")),{meridiemMode:f,handleMeridiemChange:P}=(0,Yl.r7)(o,l,i),y=a,g=Zl((0,na.A)({},y,{theme:p})),x=(0,ga.jsx)(_l,{tabIndex:-1,value:":",variant:"h3",selected:!1,className:g.separator});return(0,ga.jsxs)(Xl,(0,na.A)({landscapeDirection:"row",toolbarTitle:h.timePickerToolbarTitle,isLandscape:r,ownerState:y,className:(0,Xa.A)(g.root,m)},b,{children:[(0,ga.jsxs)(Gl,{className:g.hourMinuteLabel,ownerState:y,children:[(0,Al.Xk)(d,"hours")&&(0,ga.jsx)(Fl.R,{tabIndex:-1,variant:"h3",onClick:()=>s("hours"),selected:"hours"===n,value:o?(v=o,l?T.format(v,"hours12h"):T.format(v,"hours24h")):"--"}),(0,Al.Xk)(d,["hours","minutes"])&&x,(0,Al.Xk)(d,"minutes")&&(0,ga.jsx)(Fl.R,{tabIndex:-1,variant:"h3",onClick:()=>s("minutes"),selected:"minutes"===n,value:o?T.format(o,"minutes"):"--"}),(0,Al.Xk)(d,["minutes","seconds"])&&x,(0,Al.Xk)(d,"seconds")&&(0,ga.jsx)(Fl.R,{variant:"h3",onClick:()=>s("seconds"),selected:"seconds"===n,value:o?T.format(o,"seconds"):"--"})]}),k&&(0,ga.jsxs)(Jl,{className:g.ampmSelection,ownerState:y,children:[(0,ga.jsx)(Fl.R,{disableRipple:!0,variant:"subtitle2",selected:"am"===f,typographyClassName:g.ampmLabel,value:(0,pa._S)(T,"am"),onClick:c?void 0:()=>P("am"),disabled:u}),(0,ga.jsx)(Fl.R,{disableRipple:!0,variant:"subtitle2",selected:"pm"===f,typographyClassName:g.ampmLabel,value:(0,pa._S)(T,"pm"),onClick:c?void 0:()=>P("pm"),disabled:u})]})]}));var v}function et(e,a){var l,t,o,r,i;const n=(0,ka.hc)(),s=(0,ca.A)({props:e,name:a}),d=null!=(l=s.ampm)?l:n.is12HourCycleInCurrentLocale(),u=da.useMemo((()=>{var e;return null==(null==(e=s.localeText)?void 0:e.toolbarTitle)?s.localeText:(0,na.A)({},s.localeText,{timePickerToolbarTitle:s.localeText.toolbarTitle})}),[s.localeText]),c=null!=(t=s.slots)?t:(0,vl.p)(s.components),m=null!=(o=s.slotProps)?o:s.componentsProps;return(0,na.A)({},s,{ampm:d,localeText:u},(0,Tl.R)({views:s.views,openTo:s.openTo,defaultViews:["hours","minutes"],defaultOpenTo:"hours"}),{disableFuture:null!=(r=s.disableFuture)&&r,disablePast:null!=(i=s.disablePast)&&i,slots:(0,na.A)({toolbar:Ql},c),slotProps:(0,na.A)({},m,{toolbar:(0,na.A)({ampm:d,ampmInClock:s.ampmInClock},null==m?void 0:m.toolbar)})})}Jl.propTypes={as:Za().elementType,ownerState:Za().object.isRequired,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object])};var at=l(50771),lt=l(95878),tt=l(81589);const ot=da.forwardRef((function(e,a){var l,t,o,r,i,n;const s=(0,ka.Nq)(),d=(0,ka.hc)(),u=et(e,"MuiDesktopTimePicker"),{shouldRenderTimeInASingleColumn:c,views:m,timeSteps:b}=(0,tt.H)(u),T=c?at.$W:at.$8,h=(0,na.A)({hours:T,minutes:T,seconds:T,meridiem:T},u.viewRenderers),p=null==(l=u.ampmInClock)||l,k=c?[]:["accept"],f=(null==(t=h.hours)?void 0:t.name)===at.$8.name?m:m.filter((e=>"meridiem"!==e)),P=(0,na.A)({},u,{ampmInClock:p,timeSteps:b,viewRenderers:h,format:(0,lt.b$)(d,u),views:c?["hours"]:f,slots:(0,na.A)({field:Va,openPickerIcon:Dl.O4},u.slots),slotProps:(0,na.A)({},u.slotProps,{field:e=>{var l;return(0,na.A)({},(0,ml.Y)(null==(l=u.slotProps)?void 0:l.field,e),(0,$l.zd)(u),{ref:a})},toolbar:(0,na.A)({hidden:!0,ampmInClock:p},null==(o=u.slotProps)?void 0:o.toolbar),actionBar:(0,na.A)({actions:k},null==(r=u.slotProps)?void 0:r.actionBar)})}),{renderPicker:y}=(0,Ll.U)({props:P,valueManager:ba.W,valueType:"time",getOpenDialogAriaText:null!=(i=null==(n=P.localeText)?void 0:n.openTimePickerDialogue)?i:s.openTimePickerDialogue,validator:Da.i});return y()}));ot.propTypes={ampm:Za().bool,ampmInClock:Za().bool,autoFocus:Za().bool,className:Za().string,closeOnSelect:Za().bool,components:Za().object,componentsProps:Za().object,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableIgnoringDatePartForTimeValidation:Za().bool,disableOpenPicker:Za().bool,disablePast:Za().bool,format:Za().string,formatDensity:Za().oneOf(["dense","spacious"]),inputRef:bl.A,label:Za().node,localeText:Za().object,maxTime:Za().any,minTime:Za().any,minutesStep:Za().number,name:Za().string,onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onOpen:Za().func,onSelectedSectionsChange:Za().func,onViewChange:Za().func,open:Za().bool,openTo:Za().oneOf(["hours","meridiem","minutes","seconds"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,selectedSections:Za().oneOfType([Za().oneOf(["all","day","hours","meridiem","minutes","month","seconds","weekDay","year"]),Za().number,Za().shape({endIndex:Za().number.isRequired,startIndex:Za().number.isRequired})]),shouldDisableClock:Za().func,shouldDisableTime:Za().func,skipDisabled:Za().bool,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),thresholdToRenderTimeInASingleColumn:Za().number,timeSteps:Za().shape({hours:Za().number,minutes:Za().number,seconds:Za().number}),timezone:Za().string,value:Za().any,view:Za().oneOf(["hours","meridiem","minutes","seconds"]),viewRenderers:Za().shape({hours:Za().func,meridiem:Za().func,minutes:Za().func,seconds:Za().func}),views:Za().arrayOf(Za().oneOf(["hours","minutes","seconds"]).isRequired)};const rt=da.forwardRef((function(e,a){var l,t,o,r;const i=(0,ka.Nq)(),n=(0,ka.hc)(),s=et(e,"MuiMobileTimePicker"),d=(0,na.A)({hours:at.Zo,minutes:at.Zo,seconds:at.Zo},s.viewRenderers),u=null!=(l=s.ampmInClock)&&l,c=(0,na.A)({},s,{ampmInClock:u,viewRenderers:d,format:(0,lt.b$)(n,s),slots:(0,na.A)({field:Va},s.slots),slotProps:(0,na.A)({},s.slotProps,{field:e=>{var l;return(0,na.A)({},(0,ml.Y)(null==(l=s.slotProps)?void 0:l.field,e),(0,$l.zd)(s),{ref:a})},toolbar:(0,na.A)({hidden:!1,ampmInClock:u},null==(t=s.slotProps)?void 0:t.toolbar)})}),{renderPicker:m}=(0,Cl.C)({props:c,valueManager:ba.W,valueType:"time",getOpenDialogAriaText:null!=(o=null==(r=c.localeText)?void 0:r.openTimePickerDialogue)?o:i.openTimePickerDialogue,validator:Da.i});return m()}));rt.propTypes={ampm:Za().bool,ampmInClock:Za().bool,autoFocus:Za().bool,className:Za().string,closeOnSelect:Za().bool,components:Za().object,componentsProps:Za().object,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableIgnoringDatePartForTimeValidation:Za().bool,disableOpenPicker:Za().bool,disablePast:Za().bool,format:Za().string,formatDensity:Za().oneOf(["dense","spacious"]),inputRef:bl.A,label:Za().node,localeText:Za().object,maxTime:Za().any,minTime:Za().any,minutesStep:Za().number,name:Za().string,onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onOpen:Za().func,onSelectedSectionsChange:Za().func,onViewChange:Za().func,open:Za().bool,openTo:Za().oneOf(["hours","minutes","seconds"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,selectedSections:Za().oneOfType([Za().oneOf(["all","day","hours","meridiem","minutes","month","seconds","weekDay","year"]),Za().number,Za().shape({endIndex:Za().number.isRequired,startIndex:Za().number.isRequired})]),shouldDisableClock:Za().func,shouldDisableTime:Za().func,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),timezone:Za().string,value:Za().any,view:Za().oneOf(["hours","minutes","seconds"]),viewRenderers:Za().shape({hours:Za().func,minutes:Za().func,seconds:Za().func}),views:Za().arrayOf(Za().oneOf(["hours","minutes","seconds"]).isRequired)};const it=["desktopModeMediaQuery"],nt=da.forwardRef((function(e,a){const l=(0,ca.A)({props:e,name:"MuiTimePicker"}),{desktopModeMediaQuery:t=Al.jX}=l,o=(0,sa.A)(l,it);return(0,cl.A)(t,{defaultMatches:!0})?(0,ga.jsx)(ot,(0,na.A)({ref:a},o)):(0,ga.jsx)(rt,(0,na.A)({ref:a},o))})),st=da.forwardRef((function(e,a){var l,t,o;const r=et(e,"MuiStaticTimePicker"),i=null!=(l=r.displayStaticWrapperAs)?l:"mobile",n=null!=(t=r.ampmInClock)?t:"desktop"===i,s=(0,na.A)({hours:at.Zo,minutes:at.Zo,seconds:at.Zo},r.viewRenderers),d=(0,na.A)({},r,{viewRenderers:s,displayStaticWrapperAs:i,ampmInClock:n,slotProps:(0,na.A)({},r.slotProps,{toolbar:(0,na.A)({hidden:"desktop"===i,ampmInClock:n},null==(o=r.slotProps)?void 0:o.toolbar)})}),{renderPicker:u}=El({props:d,valueManager:ba.W,valueType:"time",validator:Da.i,ref:a});return u()}));st.propTypes={ampm:Za().bool,ampmInClock:Za().bool,autoFocus:Za().bool,className:Za().string,components:Za().object,componentsProps:Za().object,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableIgnoringDatePartForTimeValidation:Za().bool,disablePast:Za().bool,displayStaticWrapperAs:Za().oneOf(["desktop","mobile"]),localeText:Za().object,maxTime:Za().any,minTime:Za().any,minutesStep:Za().number,onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onViewChange:Za().func,openTo:Za().oneOf(["hours","minutes","seconds"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,shouldDisableClock:Za().func,shouldDisableTime:Za().func,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),timezone:Za().string,value:Za().any,view:Za().oneOf(["hours","minutes","seconds"]),viewRenderers:Za().shape({hours:Za().func,minutes:Za().func,seconds:Za().func}),views:Za().arrayOf(Za().oneOf(["hours","minutes","seconds"]).isRequired)};var dt=l(73643),ut=l(70407),ct=l(58099),mt=l(6476),bt=l(26438),Tt=l(78667),ht=l(47963),pt=l(70333),kt=l(79696);const ft=da.forwardRef((function(e,a){var l,t,o,r,i;const n=(0,pt.u)(e,"MuiStaticDateTimePicker"),s=null!=(l=n.displayStaticWrapperAs)?l:"mobile",d=null!=(t=n.ampmInClock)?t:"desktop"===s,u=(0,na.A)({day:wl.W,month:wl.W,year:wl.W,hours:at.Zo,minutes:at.Zo,seconds:at.Zo},n.viewRenderers),c=(0,na.A)({},n,{viewRenderers:u,displayStaticWrapperAs:s,ampmInClock:d,yearsPerRow:null!=(o=n.yearsPerRow)?o:"mobile"===s?3:4,slotProps:(0,na.A)({},n.slotProps,{tabs:(0,na.A)({hidden:"desktop"===s},null==(r=n.slotProps)?void 0:r.tabs),toolbar:(0,na.A)({hidden:"desktop"===s,ampmInClock:d},null==(i=n.slotProps)?void 0:i.toolbar)})}),{renderPicker:m}=El({props:c,valueManager:ba.W,valueType:"date-time",validator:kt.q,ref:a});return m()}));ft.propTypes={ampm:Za().bool,ampmInClock:Za().bool,autoFocus:Za().bool,className:Za().string,components:Za().object,componentsProps:Za().object,dayOfWeekFormatter:Za().func,defaultCalendarMonth:Za().any,defaultValue:Za().any,disabled:Za().bool,disableFuture:Za().bool,disableHighlightToday:Za().bool,disableIgnoringDatePartForTimeValidation:Za().bool,disablePast:Za().bool,displayStaticWrapperAs:Za().oneOf(["desktop","mobile"]),displayWeekNumber:Za().bool,fixedWeekNumber:Za().number,loading:Za().bool,localeText:Za().object,maxDate:Za().any,maxDateTime:Za().any,maxTime:Za().any,minDate:Za().any,minDateTime:Za().any,minTime:Za().any,minutesStep:Za().number,monthsPerRow:Za().oneOf([3,4]),onAccept:Za().func,onChange:Za().func,onClose:Za().func,onError:Za().func,onMonthChange:Za().func,onViewChange:Za().func,onYearChange:Za().func,openTo:Za().oneOf(["day","hours","minutes","month","seconds","year"]),orientation:Za().oneOf(["landscape","portrait"]),readOnly:Za().bool,reduceAnimations:Za().bool,referenceDate:Za().any,renderLoading:Za().func,shouldDisableClock:Za().func,shouldDisableDate:Za().func,shouldDisableMonth:Za().func,shouldDisableTime:Za().func,shouldDisableYear:Za().func,showDaysOutsideCurrentMonth:Za().bool,slotProps:Za().object,slots:Za().object,sx:Za().oneOfType([Za().arrayOf(Za().oneOfType([Za().func,Za().object,Za().bool])),Za().func,Za().object]),timezone:Za().string,value:Za().any,view:Za().oneOf(["day","hours","minutes","month","seconds","year"]),viewRenderers:Za().shape({day:Za().func,hours:Za().func,minutes:Za().func,month:Za().func,seconds:Za().func,year:Za().func}),views:Za().arrayOf(Za().oneOf(["day","hours","minutes","month","seconds","year"]).isRequired),yearsPerRow:Za().oneOf([3,4])};var Pt=l(73721),yt=l(89827),gt=l(29885),xt=l(1909)}}]);