"use strict";(self.webpackChunkgrader_labextension=self.webpackChunkgrader_labextension||[]).push([[740],{73788:(e,n,u)=>{u.d(n,{A:()=>d,I:()=>i});var t=u(55285),l=u(40644),a=u(93345),r=u(74848);const o=["value"],s=a.createContext(),i=()=>{const e=a.useContext(s);return null!=e&&e},d=function(e){let{value:n}=e,u=(0,l.A)(e,o);return(0,r.jsx)(s.Provider,(0,t.A)({value:null==n||n},u))}},29069:(e,n,u)=>{u.d(n,{A:()=>l});var t=u(93345);function l(e,n){var u,l;return t.isValidElement(e)&&-1!==n.indexOf(null!=(u=e.type.muiName)?u:null==(l=e.type)||null==(l=l._payload)||null==(l=l.value)?void 0:l.muiName)}},50173:(e,n,u)=>{u.d(n,{A:()=>l});var t=u(93345);const l="undefined"!=typeof window?t.useLayoutEffect:t.useEffect}}]);