/**
 * Grader Extension API Schemas
 *
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
import { SubmissionPeriod } from './submissionPeriod';


export interface AssignmentSettings { 
    late_submission?: Array<SubmissionPeriod>;
}

