/*! For license information please see 848.dfd1a8c4ef4cb7cd0042.js.LICENSE.txt */
"use strict";(self.webpackChunkgrader_labextension=self.webpackChunkgrader_labextension||[]).push([[848],{21020:(e,r,o)=>{var t=o(93345),n=Symbol.for("react.element"),a=Symbol.for("react.fragment"),s=Object.prototype.hasOwnProperty,_=t.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentOwner,f={key:!0,ref:!0,__self:!0,__source:!0};function l(e,r,o){var t,a={},l=null,p=null;for(t in void 0!==o&&(l=""+o),void 0!==r.key&&(l=""+r.key),void 0!==r.ref&&(p=r.ref),r)s.call(r,t)&&!f.hasOwnProperty(t)&&(a[t]=r[t]);if(e&&e.defaultProps)for(t in r=e.defaultProps)void 0===a[t]&&(a[t]=r[t]);return{$$typeof:n,type:e,key:l,ref:p,props:a,_owner:_.current}}r.Fragment=a,r.jsx=l,r.jsxs=l},74848:(e,r,o)=>{e.exports=o(21020)}}]);