"use strict";(self.webpackChunkgrader_labextension=self.webpackChunkgrader_labextension||[]).push([[336,285,955],{55285:(n,r,e)=>{function a(){return a=Object.assign?Object.assign.bind():function(n){for(var r=1;r<arguments.length;r++){var e=arguments[r];for(var a in e)({}).hasOwnProperty.call(e,a)&&(n[a]=e[a])}return n},a.apply(null,arguments)}e.d(r,{A:()=>a})},40644:(n,r,e)=>{function a(n,r){if(null==n)return{};var e={};for(var a in n)if({}.hasOwnProperty.call(n,a)){if(r.indexOf(a)>=0)continue;e[a]=n[a]}return e}e.d(r,{A:()=>a})}}]);